<?php

return [
    'number.decimals_separator' => ',',
    'number.thousands_separator' => '.',
    'None' => 'None',
    'Edit' => 'Uredi',
    'Remove' => 'Ukloni',
    'Yes' => 'Da',
    'No' => 'Ne',
    'cancel' => 'odustani',
    'or' => 'ili',
    'Yellow' => 'Žuta',
    'Blue' => 'Plava',
    'Green' => 'Zelena',
    'Purple' => 'Ljubičasta',
    'Red' => 'Crvena',
    'Orange' => 'Narandžasta',
    'Grey' => 'Siva',
    'Brown' => 'Smeđa',
    'Deep Orange' => 'Tamno narandžasta',
    'Dark Grey' => 'Tamno siva',
    'Pink' => 'Roze',
    'Teal' => 'Tirkizna',
    'Cyan' => 'Zelenkasto plava',
    'Lime' => 'Žućkasto zelena',
    'Light Green' => 'Svijetlo zelena',
    'Amber' => 'Ćilibarska',
    'Save' => 'Sačuvaj',
    'Login' => 'Prijava',
    'Official website:' => 'Zvanična stranica:',
    'Unassigned' => 'Nedodijeljen',
    'View this task' => 'Pregledaj zadatak',
    'Remove user' => 'Ukloni korisnika',
    'Do you really want to remove this user: "%s"?' => 'Da li zaista želiš da ukloniš korisnika: "%s"?',
    'All users' => 'Svi korisnici',
    'Username' => 'Korisničko ime',
    'Password' => 'Šifra',
    'Administrator' => 'Administrator',
    'Sign in' => 'Prijava',
    'Users' => 'Korisnici',
    'Forbidden' => 'Zabranjeno',
    'Access Forbidden' => 'Pristup zabranjen',
    'Edit user' => 'Uredi korisnika',
    'Logout' => 'Odjava',
    'Bad username or password' => 'Pogrešno korisničko ime ili šifra',
    'Edit project' => 'Uredi projekat',
    'Name' => 'Ime',
    'Projects' => 'Projekti',
    'No project' => 'Bez projekta',
    'Project' => 'Projekat',
    'Status' => 'Status',
    'Tasks' => 'Zadaci',
    'Board' => 'Ploča',
    'Actions' => 'Akcije',
    'Inactive' => 'Neaktivan',
    'Active' => 'Aktivan',
    'Unable to update this board.' => 'Nemogu da ažuriram ovu ploču.',
    'Disable' => 'Onemogući',
    'Enable' => 'Omogući',
    'New project' => 'Novi projekat',
    'Do you really want to remove this project: "%s"?' => 'Da li zaista želiš ukloniti projekat: "%s"?',
    'Remove project' => 'Ukloni projekat',
    'Edit the board for "%s"' => 'Uredi ploču za "%s"',
    'Add a new column' => 'Dodaj novu kolonu',
    'Title' => 'Naslov',
    'Assigned to %s' => 'Dodijeljen korisniku %s',
    'Remove a column' => 'Ukloni kolonu',
    'Unable to remove this column.' => 'Nemoguće uklanjanje kolone.',
    'Do you really want to remove this column: "%s"?' => 'Da li zaista želiš da ukoniš ovu kolonu: "%s"?',
    'Settings' => 'Podešavanja',
    'Application settings' => 'Podešavanja aplikacije',
    'Language' => 'Jezik',
    'Webhook token:' => 'Token:',
    'API token:' => 'Token za API',
    'Database size:' => 'Veličina baze:',
    'Download the database' => 'Preuzmi bazu',
    'Optimize the database' => 'Optimizuj bazu',
    '(VACUUM command)' => '(Naredba VACUUM)',
    '(Gzip compressed Sqlite file)' => '(Sqlite baza spakovana Gzip-om)',
    'Close a task' => 'Zatvori zadatak',
    'Column' => 'Kolona',
    'Color' => 'Boja',
    'Assignee' => 'Izvršilac',
    'Create another task' => 'Poslije ovoga autoamtski otvori formu za dodavanje novog zadatka',
    'New task' => 'Novi zadatak',
    'Open a task' => 'Otvori zadatak',
    'Do you really want to open this task: "%s"?' => 'Da li zaista želiš da otvoriš zadatak: "%s"?',
    'Back to the board' => 'Nazad na ploču',
    'There is nobody assigned' => 'Niko nije dodijeljen!',
    'Column on the board:' => 'Kolona na tabli:',
    'Close this task' => 'Zatvori ovaj zadatak',
    'Open this task' => 'Otvori ovaj zadatak',
    'There is no description.' => 'Bez opisa.',
    'Add a new task' => 'Dodaj novi zadatak',
    'The username is required' => 'Korisničko ime je obavezno',
    'The maximum length is %d characters' => 'Maksimalna dužina je %d znakova',
    'The minimum length is %d characters' => 'Minimalna dužina je %d znakova',
    'The password is required' => 'Šifra je obavezna',
    'This value must be an integer' => 'Mora biti cio broj',
    'The username must be unique' => 'Korisničko ime mora biti jedinstveno',
    'The user id is required' => 'ID korisnika je obavezan',
    'Passwords don\'t match' => 'Šifre se ne podudaraju',
    'The confirmation is required' => 'Potvrda je obavezna',
    'The project is required' => 'Projekat je obavezan',
    'The id is required' => 'ID  je obavezan',
    'The project id is required' => 'ID projekta  je obavezan',
    'The project name is required' => 'Naziv projekta je obavezan',
    'The title is required' => 'Naslov je obavezan',
    'Settings saved successfully.' => 'Podešavanja uspješno sačuvana.',
    'Unable to save your settings.' => 'Nemoguće sačuvati podešavanja.',
    'Database optimization done.' => 'Optimizacija baze je završena.',
    'Your project has been created successfully.' => 'Projekat je uspješno napravljen.',
    'Unable to create your project.' => 'Nemoguće kreiranje projekta.',
    'Project updated successfully.' => 'Projekat je uspješno ažuriran.',
    'Unable to update this project.' => 'Nemoguće ažuriranje projekta.',
    'Unable to remove this project.' => 'Nemoguće uklanjanje projekta.',
    'Project removed successfully.' => 'Projekat uspješno uklonjen.',
    'Project activated successfully.' => 'Projekt uspješno aktiviran.',
    'Unable to activate this project.' => 'Nemoguće aktiviranje projekta.',
    'Project disabled successfully.' => 'Projekat uspješno deaktiviran.',
    'Unable to disable this project.' => 'nemoguće deaktiviranje projekta.',
    'Unable to open this task.' => 'Nemoguće otvaranje zadatka.',
    'Task opened successfully.' => 'Zadatak uspješno otvoren.',
    'Unable to close this task.' => 'Nije moguće zatvaranje ovog zadatka.',
    'Task closed successfully.' => 'Zadatak uspješno zatvoren.',
    'Unable to update your task.' => 'Nije moguće ažuriranje zadatka.',
    'Task updated successfully.' => 'Zadatak uspješno ažuriran.',
    'Unable to create your task.' => 'Nije moguće kreiranje zadatka.',
    'Task created successfully.' => 'Zadatak uspješno kreiran.',
    'User created successfully.' => 'Korisnik uspješno kreiran',
    'Unable to create your user.' => 'Nije uspjelo kreiranje korisnika.',
    'User updated successfully.' => 'Korisnik uspješno ažuriran.',
    'User removed successfully.' => 'Korisnik uspješno uklonjen.',
    'Unable to remove this user.' => 'Nije moguće uklanjanje korisnika.',
    'Board updated successfully.' => 'Ploča je uspješno ažurirana.',
    'Ready' => 'Spreman',
    'Backlog' => 'Zaliha',
    'Work in progress' => 'U izradi',
    'Done' => 'Gotovo',
    'Application version:' => 'Verzija aplikacije:',
    'Id' => 'Id',
    'Public link' => 'Javni link',
    'Timezone' => 'Vremenska zona',
    'Sorry, I didn\'t find this information in my database!' => 'Na žalost, nije pronađena informacija u bazi',
    'Page not found' => 'Strana nije pronađena',
    'Complexity' => 'Složenost',
    'Task limit' => 'Najviše zadataka',
    'Task count' => 'Broj zadataka',
    'User' => 'Korisnik',
    'Comments' => 'Komentari',
    'Comment is required' => 'Komentar je obavezan',
    'Comment added successfully.' => 'Komentar uspješno dodan',
    'Unable to create your comment.' => 'Nemoguće kreiranje komentara',
    'Due Date' => 'Treba biti gotovo do dana',
    'Invalid date' => 'Pogrešan datum',
    'Automatic actions' => 'Automatske akcije',
    'Your automatic action has been created successfully.' => 'Uspješno kreirana automatska akcija',
    'Unable to create your automatic action.' => 'Nemoguće kreiranje automatske akcije',
    'Remove an action' => 'Obriši akciju',
    'Unable to remove this action.' => 'Nije moguće obrisati akciju',
    'Action removed successfully.' => 'Akcija obrisana',
    'Automatic actions for the project "%s"' => 'Akcije za automatizaciju projekta "%s"',
    'Add an action' => 'dodaj akcju',
    'Event name' => 'Naziv događaja',
    'Action' => 'Akcija',
    'Event' => 'Događaj',
    'When the selected event occurs execute the corresponding action.' => 'Na izabrani događaj izvrši odgovarajuću akciju',
    'Next step' => 'Slijedeći korak',
    'Define action parameters' => 'Definiši parametre akcije',
    'Do you really want to remove this action: "%s"?' => 'Da li da obrišem akciju "%s"?',
    'Remove an automatic action' => 'Obriši automatsku akciju',
    'Assign the task to a specific user' => 'Dodijeli zadatak određenom korisniku',
    'Assign the task to the person who does the action' => 'Dodeli zadatak korisniku koji je izvršio akciju',
    'Duplicate the task to another project' => 'Kopiraj akciju u drugi projekat',
    'Move a task to another column' => 'Premjesti zadatak u drugu kolonu',
    'Task modification' => 'Izmjene zadatka',
    'Task creation' => 'Kreiranje zadatka',
    'Closing a task' => 'Zatvaranja zadatka',
    'Assign a color to a specific user' => 'Dodeli boju korisniku',
    'Position' => 'Pozicija',
    'Duplicate to project' => 'Dupliciraj u drugi projekat',
    'Duplicate' => 'Dupliciraj',
    'Link' => 'Link',
    'Comment updated successfully.' => 'Komentar uspješno ažuriran.',
    'Unable to update your comment.' => 'Neuspješno ažuriranje komentara.',
    'Remove a comment' => 'Obriši komentar',
    'Comment removed successfully.' => 'Komentar je uspješno obrisan.',
    'Unable to remove this comment.' => 'Neuspješno brisanje komentara.',
    'Do you really want to remove this comment?' => 'Da li zaista želiš obrisati ovaj komentar?',
    'Current password for the user "%s"' => 'Trenutna šifra korisnika "%s"',
    'The current password is required' => 'Trenutna šifra je obavezna',
    'Wrong password' => 'Pogrešna šifra',
    'Unknown' => 'Nepoznat',
    'Last logins' => 'Posljednje prijave',
    'Login date' => 'Datum prijave',
    'Authentication method' => 'Metod autentikacije',
    'IP address' => 'IP adresa',
    'User agent' => 'Browser',
    'Persistent connections' => 'Stalna konekcija',
    'No session.' => 'Bez sesije',
    'Expiration date' => 'Ističe',
    'Remember Me' => 'Zapamti me',
    'Creation date' => 'Datum kreiranja',
    'Everybody' => 'Svi',
    'Open' => 'Otvoreni',
    'Closed' => 'Zatvoreni',
    'Search' => 'Pretraga',
    'Nothing found.' => 'Ništa nije pronađeno',
    'Due date' => 'Treba biti gotovo do dana',
    'Description' => 'Opis',
    '%d comments' => '%d Komentara',
    '%d comment' => '%d Komentar',
    'Email address invalid' => 'Pogrešan e-mail',
    'Your external account is not linked anymore to your profile.' => 'Tvoj vanjski korisnički profil nije više povezan.',
    'Unable to unlink your external account.' => 'Nemoguće ukloniti vezu s vanjskim korisničkim profilom',
    'External authentication failed' => 'Vanjska autentikacija nije uspostavljena',
    'Your external account is linked to your profile successfully.' => 'Uspješno uspostavljena vanjska autentikacija',
    'Email' => 'E-mail',
    'Task removed successfully.' => 'Zadatak uspješno uklonjen.',
    'Unable to remove this task.' => 'Nemoguće uklanjanje zadatka.',
    'Remove a task' => 'Ukloni zadatak',
    'Do you really want to remove this task: "%s"?' => 'Da li zaista želiš ukloniti zadatak "%s"?',
    'Assign automatically a color based on a category' => 'Automatski dodijeli boju po kategoriji',
    'Assign automatically a category based on a color' => 'Automatski dodijeli kategoriju po boji',
    'Task creation or modification' => 'Kreiranje ili izmjena zadatka',
    'Category' => 'Kategorija',
    'Category:' => 'Kategorija:',
    'Categories' => 'Kategorije',
    'Your category has been created successfully.' => 'Uspješno kreirana kategorija.',
    'This category has been updated successfully.' => 'Kategorija je uspješno ažurirana',
    'Unable to update this category.' => 'Nemoguće izmijeniti kategoriju',
    'Remove a category' => 'Ukloni kategoriju',
    'Category removed successfully.' => 'Kategorija uspješno uklonjena.',
    'Unable to remove this category.' => 'Nije moguće ukloniti kategoriju.',
    'Category modification for the project "%s"' => 'Izmjena kategorije za projekat "%s"',
    'Category Name' => 'Naziv kategorije',
    'Add a new category' => 'Dodaj novu kategoriju',
    'Do you really want to remove this category: "%s"?' => 'Da li zaista želiš ukloniti kategoriju: "%s"?',
    'All categories' => 'Sve kategorije',
    'No category' => 'Bez kategorije',
    'The name is required' => 'Naziv je obavezan',
    'Remove a file' => 'Ukloni datoteku',
    'Unable to remove this file.' => 'Fajl nije moguće ukloniti.',
    'File removed successfully.' => 'Uspješno uklonjena datoteka.',
    'Attach a document' => 'Prikači dokument',
    'Do you really want to remove this file: "%s"?' => 'Da li zaista želiš ukloniti datoteku: "%s"?',
    'Attachments' => 'Prilozi',
    'Edit the task' => 'Uredi zadatak',
    'Add a comment' => 'Dodaj komentar',
    'Edit a comment' => 'Izmijeni komentar',
    'Summary' => 'Pregled',
    'Time tracking' => 'Praćenje vremena',
    'Estimate:' => 'Procjena:',
    'Spent:' => 'Potrošeno:',
    'Do you really want to remove this sub-task?' => 'Da li da zaista želiš ukloniti pod-zdadatak?',
    'Remaining:' => 'Preostalo:',
    'hours' => 'sati',
    'estimated' => 'procijenjeno',
    'Sub-Tasks' => 'Pod-zadaci',
    'Add a sub-task' => 'Dodaj pod-zadatak',
    'Original estimate' => 'Originalna procjena',
    'Create another sub-task' => 'Dodaj novi pod-zadatak',
    'Time spent' => 'Utrošeno vrijeme',
    'Edit a sub-task' => 'Izmijeni pod-zadatak',
    'Remove a sub-task' => 'Ukloni pod-zadatak',
    'The time must be a numeric value' => 'Vrijeme mora biti broj',
    'Todo' => 'Za uraditi',
    'In progress' => 'U radu',
    'Sub-task removed successfully.' => 'Pod-zadatak uspješno uklonjen.',
    'Unable to remove this sub-task.' => 'Nemoguće ukloniti pod-zadatak.',
    'Sub-task updated successfully.' => 'Pod-zadatak uspješno ažuriran.',
    'Unable to update your sub-task.' => 'Nemoguće ažurirati pod-zadatak.',
    'Unable to create your sub-task.' => 'Nemoguće dodati pod-zadatak.',
    'Maximum size: ' => 'Maksimalna veličina: ',
    'Display another project' => 'Prikaži drugi projekat',
    'Created by %s' => 'Kreirao %s',
    'Tasks Export' => 'Izvoz zadataka',
    'Start Date' => 'Početni datum',
    'Execute' => 'Izvrši',
    'Task Id' => 'Identifikator zadatka',
    'Creator' => 'Autor',
    'Modification date' => 'Datum izmjene',
    'Completion date' => 'Datum završetka',
    'Clone' => 'Kloniraj',
    'Project cloned successfully.' => 'Projekat uspješno kloniran.',
    'Unable to clone this project.' => 'Nije moguće klonirati projekat.',
    'Enable email notifications' => 'Omogući obavještenja e-mailom',
    'Task position:' => 'Pozicija zadatka:',
    'The task #%d has been opened.' => 'Zadatak #%d je otvoren.',
    'The task #%d has been closed.' => 'Zadatak #%d je zatvoren.',
    'Sub-task updated' => 'Pod-zadatak izmijenjen',
    'Title:' => 'Naslov:',
    'Status:' => 'Status:',
    'Assignee:' => 'Izvršilac:',
    'Time tracking:' => 'Praćenje vremena:',
    'New sub-task' => 'Novi pod-zadatak',
    'New attachment added "%s"' => 'Ubačen novi prilog "%s"',
    'New comment posted by %s' => '%s ostavio novi komentar',
    'New comment' => 'Novi komentar',
    'Comment updated' => 'Komentar ažuriran',
    'New subtask' => 'Novi pod-zadatak',
    'I only want to receive notifications for these projects:' => 'Želim obavještenja samo za ove projekte:',
    'view the task on Kanboard' => 'Pregledaj zadatke',
    'Public access' => 'Javni pristup',
    'Disable public access' => 'Zabrani javni pristup',
    'Enable public access' => 'Dozvoli javni pristup',
    'Public access disabled' => 'Javni pristup onemogućen!',
    'Move the task to another project' => 'Premjesti zadatak u drugi projekat',
    'Move to project' => 'Premjesti u drugi projekat',
    'Do you really want to duplicate this task?' => 'Da li zaista želiš duplicirati ovaj zadatak?',
    'Duplicate a task' => 'Dupliciraj zadatak',
    'External accounts' => 'Vanjski korisnički računi',
    'Account type' => 'Tip korisničkog računa',
    'Local' => 'Lokalno',
    'Remote' => 'Udaljeno',
    'Enabled' => 'Omogućeno',
    'Disabled' => 'Onemogućeno',
    'Login:' => 'Korisničko ime:',
    'Full Name:' => 'Ime i Prezime',
    'Email:' => 'Email: ',
    'Notifications:' => 'Obavještenja: ',
    'Notifications' => 'Obavještenja',
    'Account type:' => 'Vrsta korisničkog računa:',
    'Edit profile' => 'Uredi profil',
    'Change password' => 'Promijeni šifru',
    'Password modification' => 'Izmjena šifre',
    'External authentications' => 'Vanjske autentikacije',
    'Never connected.' => 'Bez konekcija.',
    'No external authentication enabled.' => 'Bez omogućenih vanjskih autentikacija.',
    'Password modified successfully.' => 'Uspješna izmjena šifre.',
    'Unable to change the password.' => 'Nije moguće izmijeniti šifru.',
    'Change category' => 'Izmijeni kategoriju',
    '%s updated the task %s' => '%s izmijenio zadatak %s',
    '%s opened the task %s' => '%s otvorio zadatak %s',
    '%s moved the task %s to the position #%d in the column "%s"' => '%s premjestio zadatak %s na poziciju #%d u koloni "%s"',
    '%s moved the task %s to the column "%s"' => '%s premjestio zadatak %s u kolonu "%s"',
    '%s created the task %s' => '%s kreirao zadatak %s',
    '%s closed the task %s' => '%s zatvorio zadatak %s',
    '%s created a subtask for the task %s' => '%s kreirao pod-zadatak zadatka %s',
    '%s updated a subtask for the task %s' => '%s izmijenio pod-zadatak zadatka %s',
    'Assigned to %s with an estimate of %s/%sh' => 'Dodijeljen korisniku %s uz procjenu vremena %s/%sh',
    'Not assigned, estimate of %sh' => 'Ne dodijeljen, procijenjeno vrijeme %sh',
    '%s updated a comment on the task %s' => '%s izmijenio komentar zadatka %s',
    '%s commented the task %s' => '%s komentarisao zadatak %s',
    '%s\'s activity' => 'Aktivnosti %s',
    'RSS feed' => 'RSS kanal',
    '%s updated a comment on the task #%d' => '%s izmijenio komentar zadatka #%d',
    '%s commented on the task #%d' => '%s komentarisao zadatak #%d',
    '%s updated a subtask for the task #%d' => '%s izmijenio pod-zadatak zadatka #%d',
    '%s created a subtask for the task #%d' => '%s kreirao pod-zadatak zadatka #%d',
    '%s updated the task #%d' => '%s ažurirao zadatak #%d',
    '%s created the task #%d' => '%s kreirao zadatak #%d',
    '%s closed the task #%d' => '%s zatvorio zadatak #%d',
    '%s opened the task #%d' => '%s otvorio zadatak #%d',
    'Activity' => 'Aktivnosti',
    'Default values are "%s"' => 'Podrazumijevane vrijednosti su: "%s"',
    'Default columns for new projects (Comma-separated)' => 'Podrazumijevane kolone za novi projekat (Odvojene zarezom)',
    'Task assignee change' => 'Promijena izvršioca zadatka',
    '%s changed the assignee of the task #%d to %s' => '%s zamijeni izvršioca za zadatak #%d u %s',
    '%s changed the assignee of the task %s to %s' => '%s promijenio izvršioca za zadatak %s u %s',
    'New password for the user "%s"' => 'Nova šifra korisnika "%s"',
    'Choose an event' => 'Izaberi događaj',
    'Create a task from an external provider' => 'Kreiraj zadatak preko posrednika',
    'Change the assignee based on an external username' => 'Izmijene izvršioca bazirano na vanjskom korisničkom imenu',
    'Change the category based on an external label' => 'Izmijene kategorije bazirano na vanjskoj etiketi',
    'Reference' => 'Referenca',
    'Label' => 'Etiketa',
    'Database' => 'Baza',
    'About' => 'O Kanboardu',
    'Database driver:' => 'Database driver:',
    'Board settings' => 'Postavke table',
    'Webhook settings' => 'Postavke za webhook',
    'Reset token' => 'Resetuj token',
    'API endpoint:' => 'API endpoint',
    'Refresh interval for personal board' => 'Interval osvježavanja privatnih ploča',
    'Refresh interval for public board' => 'Interval osvježavanja javnih ploča',
    'Task highlight period' => 'Period naznačavanja zadatka',
    'Period (in second) to consider a task was modified recently (0 to disable, 2 days by default)' => 'Period (u sekundama) u kom su se događale promjene na zadatku (0 je onemogućeno, 2 dana je uobičajeno)',
    'Frequency in second (60 seconds by default)' => 'Frekvencija u sekundama (60 sekundi je uobičajeno)',
    'Frequency in second (0 to disable this feature, 10 seconds by default)' => 'Frekvencija u sekundama (0 je onemogućeno u budućnosti, 10 sekundi je uobičajeno)',
    'Application URL' => 'URL aplikacije',
    'Token regenerated.' => 'Token regenerisan.',
    'Date format' => 'Format datuma',
    'ISO format is always accepted, example: "%s" and "%s"' => 'Format ISO je uvijek prihvatljiv, primjer: "%s", "%s"',
    'New personal project' => 'Novi privatni projekat',
    'This project is personal' => 'Ovaj projekat je privatan',
    'Add' => 'Dodaj',
    'Start date' => 'Datum početka',
    'Time estimated' => 'Procijenjeno vrijeme',
    'There is nothing assigned to you.' => 'Ništa ti nije dodijeljeno',
    'My tasks' => 'Moji zadaci',
    'Activity stream' => 'Spisak aktivnosti',
    'Dashboard' => 'Panel',
    'Confirmation' => 'Potvrda',
    'Webhooks' => 'Webhooks',
    'API' => 'API',
    'Create a comment from an external provider' => 'Napravi komentar preko vanjskog posrednika',
    'Project management' => 'Upravljanje projektima',
    'Columns' => 'Kolone',
    'Task' => 'Zadatak',
    'Percentage' => 'Procenat',
    'Number of tasks' => 'Broj zadataka',
    'Task distribution' => 'Podjela zadataka',
    'Analytics' => 'Analiza',
    'Subtask' => 'Pod-zadatak',
    'User repartition' => 'Zaduženja korisnika',
    'Clone this project' => 'Kloniraj ovaj projekat',
    'Column removed successfully.' => 'Kolona uspješno uklonjena.',
    'Not enough data to show the graph.' => 'Nedovoljno podataka za prikaz na grafikonu.',
    'Previous' => 'Prethodni',
    'The id must be an integer' => 'ID mora biti cjeloviti broj',
    'The project id must be an integer' => 'ID projekta mora biti cjeloviti broj',
    'The status must be an integer' => 'Status mora biti cjeloviti broj',
    'The subtask id is required' => 'ID pod-zadataka je obavezan',
    'The subtask id must be an integer' => 'ID pod-zadatka mora biti cjeloviti broj',
    'The task id is required' => 'ID zadatka je obavezan',
    'The task id must be an integer' => 'ID zadatka mora biti cjeloviti broj',
    'The user id must be an integer' => 'ID korisnika mora biti cjeloviti broj',
    'This value is required' => 'Vrijednost je obavezna',
    'This value must be numeric' => 'Vrijednost mora biti broj',
    'Unable to create this task.' => 'Nije moguće kreirati zadatak.',
    'Cumulative flow diagram' => 'Zbirni dijagram toka',
    'Daily project summary' => 'Zbirni pregled po danima',
    'Daily project summary export' => 'Izvoz zbirnog pregleda po danima',
    'Exports' => 'Izvozi',
    'This export contains the number of tasks per column grouped per day.' => 'Ovaj izvoz sadržava broj zadataka po koloni grupisanih po danima.',
    'Active swimlanes' => 'Aktivne swimlane trake',
    'Add a new swimlane' => 'Dodaj novu swimlane traku',
    'Default swimlane' => 'Podrazumijevana swimlane traka',
    'Do you really want to remove this swimlane: "%s"?' => 'Da li zaista želiš ukloniti ovu swimlane traku: "%s"?',
    'Inactive swimlanes' => 'Neaktivne swimlane trake',
    'Remove a swimlane' => 'Ukloni swimlane traku',
    'Swimlane modification for the project "%s"' => 'Izmjene swimlane trake za projekat "%s"',
    'Swimlane removed successfully.' => 'Swimlane traka uspješno uklonjena.',
    'Swimlanes' => 'Swimlane trake',
    'Swimlane updated successfully.' => 'Swimlane traka uspjeno ažurirana.',
    'Unable to remove this swimlane.' => 'Nemoguće ukloniti swimlane traku.',
    'Unable to update this swimlane.' => 'Nemoguće ažurirati swimlane traku.',
    'Your swimlane has been created successfully.' => 'Swimlane traka je uspješno kreirana.',
    'Example: "Bug, Feature Request, Improvement"' => 'Npr: "Greška, Zahtjev za izmjenama, Poboljšanje"',
    'Default categories for new projects (Comma-separated)' => 'Podrazumijevane kategorije za novi projekat',
    'Integrations' => 'Integracije',
    'Integration with third-party services' => 'Integracija sa uslugama vanjskih servisa',
    'Subtask Id' => 'ID pod-zadatka',
    'Subtasks' => 'Pod-zadaci',
    'Subtasks Export' => 'Izvoz pod-zadataka',
    'Task Title' => 'Naslov zadatka',
    'Untitled' => 'Bez naslova',
    'Application default' => 'Podrazumijevano od aplikacije',
    'Language:' => 'Jezik:',
    'Timezone:' => 'Vremenska zona:',
    'All columns' => 'Sve kolone',
    'Next' => 'Slijedeći',
    '#%d' => '#%d',
    'All swimlanes' => 'Sve swimlane trake',
    'All colors' => 'Sve boje',
    'Moved to column %s' => 'Premješten u kolonu %s',
    'User dashboard' => 'Korisnički panel',
    'Allow only one subtask in progress at the same time for a user' => 'Dozvoli samo jedan pod-zadatak "u radu" po korisniku',
    'Edit column "%s"' => 'Uredi kolonu "%s"',
    'Select the new status of the subtask: "%s"' => 'Izaberi novi status za pod-zadatak: "%s"',
    'Subtask timesheet' => 'Vremenska tabela za pod-zadatak',
    'There is nothing to show.' => 'Nema ništa za pokazati',
    'Time Tracking' => 'Praćenje vremena',
    'You already have one subtask in progress' => 'Već imaš jedan pod-zadatak "u radu"',
    'Which parts of the project do you want to duplicate?' => 'Koje delove projekta želiš duplicirati?',
    'Disallow login form' => 'Zabrani prijavnu formu',
    'Start' => 'Početak',
    'End' => 'Kraj',
    'Task age in days' => 'Trajanje zadatka u danima',
    'Days in this column' => 'Dani u ovoj  koloni',
    '%dd' => '%dd',
    'Add a new link' => 'Dodaj novu vezu',
    'Do you really want to remove this link: "%s"?' => 'Da li zaista želiš ukloniti ovu vezu: "%s"?',
    'Do you really want to remove this link with task #%d?' => 'Da li zaista želiš ukloniti ovu vezu sa zadatkom #%d?',
    'Field required' => 'Polje je obavezno',
    'Link added successfully.' => 'Veza je uspješno dodana.',
    'Link updated successfully.' => 'Veza je uspješno ažurirana.',
    'Link removed successfully.' => 'Veza je uspješno uklonjena.',
    'Link labels' => 'Veza s etiketama',
    'Link modification' => 'Veza modifikacija',
    'Opposite label' => 'Suprotna etiketa',
    'Remove a link' => 'Ukloni vezu',
    'The labels must be different' => 'Etikete moraju biti različite',
    'There is no link.' => 'Ovdje nema veza',
    'This label must be unique' => 'Ova etiketa mora biti jedinstvena',
    'Unable to create your link.' => 'Nemoguće napraviti vezu.',
    'Unable to update your link.' => 'Nemoguće ažurirati vezu.',
    'Unable to remove this link.' => 'Nemoguće ukloniti vezu.',
    'relates to' => 'relacija sa',
    'blocks' => 'blokira',
    'is blocked by' => 'je blokiran od',
    'duplicates' => 'duplicira',
    'is duplicated by' => 'je dupliciran od',
    'is a child of' => 'je dijete od',
    'is a parent of' => 'je roditelj od',
    'targets milestone' => 'cilj prekretnice',
    'is a milestone of' => 'je od prekretnice',
    'fixes' => 'popravlja',
    'is fixed by' => 'je popravljen od',
    'This task' => 'Ovaj zadatak',
    '<1h' => '<1h',
    '%dh' => '%dh',
    'Expand tasks' => 'Proširi zadatke',
    'Collapse tasks' => 'Skupi zadatke',
    'Expand/collapse tasks' => 'Proširi/skupi zadatke',
    'Close dialog box' => 'Skupi dialog',
    'Submit a form' => 'Pošalji obrazac',
    'Board view' => 'Pregled ploče',
    'Keyboard shortcuts' => 'Prečice tastature',
    'Open board switcher' => 'Otvori prekidače ploče',
    'Application' => 'Aplikacija',
    'Compact view' => 'Kompaktan pregled',
    'Horizontal scrolling' => 'Horizontalno listanje',
    'Compact/wide view' => 'Skupi/raširi pregled',
    'Currency' => 'Valuta',
    'Personal project' => 'Privatni projekat',
    'AUD - Australian Dollar' => 'AUD - Australijski dolar',
    'CAD - Canadian Dollar' => 'CAD - Kanadski dolar',
    'CHF - Swiss Francs' => 'CHF - Švicarski franak',
    'Custom Stylesheet' => 'Prilagođeni stil',
    'EUR - Euro' => 'EUR - Euro',
    'GBP - British Pound' => 'GBP - Britanska funta',
    'INR - Indian Rupee' => 'INR - Indijski rupi',
    'JPY - Japanese Yen' => 'JPY - Japanski jen',
    'NZD - New Zealand Dollar' => 'NZD - Novozelandski dolar',
    'PEN - Peruvian Sol' => 'PEN - Peruanski sol',
    'RSD - Serbian dinar' => 'RSD - Srpski dinar',
    'CNY - Chinese Yuan' => 'CNY - Kineski juan',
    'USD - US Dollar' => 'USD - Američki dolar',
    'VES - Venezuelan Bolívar' => 'VES - Venecuelanski bolivar',
    'Destination column' => 'Odredišna kolona',
    'Move the task to another column when assigned to a user' => 'Premjesti zadatak u neku drugu kolonu kada se dodijeli izvršiocu',
    'Move the task to another column when assignee is cleared' => 'Premjesti zadatak u neku drugu kolonu kada se ukloni izvršilac',
    'Source column' => 'Izvorna kolona',
    'Transitions' => 'Prelaz',
    'Executer' => 'Izvršilac',
    'Time spent in the column' => 'Vrijeme provedeno u koloni',
    'Task transitions' => 'Prelazi zadatka',
    'Task transitions export' => 'Izvezi prelaze zadatka',
    'This report contains all column moves for each task with the date, the user and the time spent for each transition.' => 'Ovaj izvještaj sadržava sve kolone premještanja za svaki zadatak s datumom, te korisnikom i utrošenim vremenom za svaki premještaj.',
    'Currency rates' => 'Stopa valute',
    'Rate' => 'Stopa',
    'Change reference currency' => 'Promijeni referencu valute',
    'Reference currency' => 'Referentna valuta',
    'The currency rate has been added successfully.' => 'Stopa valute je uspješno dodana.',
    'Unable to add this currency rate.' => 'Nemoguće dodati stopu valute.',
    'Webhook URL' => 'Webhook URL',
    '%s removed the assignee of the task %s' => '%s je uklonio izvršioca zadatka %s',
    'Information' => 'Informacije',
    'Check two factor authentication code' => 'Provjera "Dva faktora" autentifikacionog koda',
    'The two factor authentication code is not valid.' => '"Dva faktora" autentifikacionog koda nije validan.',
    'The two factor authentication code is valid.' => '"Dva faktora" autentifikacionog koda je validan.',
    'Code' => 'Kod',
    'Two factor authentication' => '"Dva faktora" autentifikacija',
    'This QR code contains the key URI: ' => 'Ovaj QR kod sadržava ključni URL: ',
    'Check my code' => 'Provjeri moj kod',
    'Secret key: ' => 'Tajni ključ: ',
    'Test your device' => 'Testiraj svoj uređaj',
    'Assign a color when the task is moved to a specific column' => 'Dodijeli boju kada je zadatak pomjeren u odabranu kolonu',
    '%s via Kanboard' => '%s uz pomoć Kanboard-a',
    'Burndown chart' => 'Grafikon izgaranja',
    'This chart show the task complexity over the time (Work Remaining).' => 'Ovaj grafikon pokazuje kompleksnost zadatka u vremenu (Preostalo vremena)',
    'Screenshot taken %s' => 'Slika ekrana uzeta %s',
    'Add a screenshot' => 'Dodaj sliku ekrana',
    'Take a screenshot and press CTRL+V or ⌘+V to paste here.' => 'Uzmi sliku ekrana i pritisni CTRL+V ili ⌘+V da zalijepiš ovdje.',
    'Screenshot uploaded successfully.' => 'Slika ekrana uspješno dodana.',
    'SEK - Swedish Krona' => 'SEK - Švedska kruna',
    'Identifier' => 'Identifikator',
    'Disable two factor authentication' => 'Onemogući "Dva faktora" autentifikaciju',
    'Do you really want to disable the two factor authentication for this user: "%s"?' => 'Da li zaista želiš onemogućiti "Dva faktora" autentifikaciju: "%s"?',
    'Edit link' => 'Uredi vezu',
    'Start to type task title...' => 'Počni pisati naslov zadatka...',
    'A task cannot be linked to itself' => 'Zadatak ne može biti povezan sa samim sobom',
    'The exact same link already exists' => 'Ista veza već postoji',
    'Recurrent task is scheduled to be generated' => 'Ponavljajući zadatak je pripremljen da bude kreiran',
    'Score' => 'Uspjeh',
    'The identifier must be unique' => 'Identifikator mora biti jedinstven',
    'This linked task id doesn\'t exists' => 'Povezani ID zadatka ne postoji',
    'This value must be alphanumeric' => 'Ova vrijednost mora biti alfanumerička',
    'Edit recurrence' => 'Uredi ponavljanje',
    'Generate recurrent task' => 'Napravi ponavljajući zadatak',
    'Trigger to generate recurrent task' => 'Okidač koji pravi ponavljajući zadatak',
    'Factor to calculate new due date' => 'Faktor za računanje novog datuma završetka',
    'Timeframe to calculate new due date' => 'Vremenski okvir za računanje novog datuma završetka',
    'Base date to calculate new due date' => 'Početni datum za računanje novog datuma završetka',
    'Action date' => 'Datum akcije',
    'Base date to calculate new due date: ' => 'Početni datum za računanje novog datuma završetka: ',
    'This task has created this child task: ' => 'Ovaj zadatak će napraviti zadatak-dijete: ',
    'Day(s)' => 'Dan(i)',
    'Existing due date' => 'Postojeći datum završetka',
    'Factor to calculate new due date: ' => 'Faktor za računanje novog datuma završetka: ',
    'Month(s)' => 'Mjesec(i)',
    'This task has been created by: ' => 'Ovaj zadatak je napravio: ',
    'Recurrent task has been generated:' => 'Ponavljajući zadatak je napravio:',
    'Timeframe to calculate new due date: ' => 'Vremenski okvir za računanje novog datuma završetka:',
    'Trigger to generate recurrent task: ' => 'Okidač za pravljenje ponavljajućeg zadatka',
    'When task is closed' => 'Kada je zadatak zatvoren',
    'When task is moved from first column' => 'Kada je zadatak premješten iz prve kolone',
    'When task is moved to last column' => 'Kada je zadatak premješten u posljednju kolonu',
    'Year(s)' => 'Godina/e',
    'Project settings' => 'Postavke projekta',
    'Automatically update the start date' => 'Automatski ažuriraj početni datum',
    'iCal feed' => 'iCal kanal',
    'Preferences' => 'Postavke',
    'Security' => 'Sigurnost',
    'Two factor authentication disabled' => '"Dva faktora" autentifikacija onemogućena',
    'Two factor authentication enabled' => '"Dva faktora" autentifikacija omogućena',
    'Unable to update this user.' => 'Nemoguće ažurirati ovog korisnika',
    'There is no user management for personal projects.' => 'Nema mehanizma za upravljanje korisnicima kod privatnih projekata.',
    'User that will receive the email' => 'Korisnik će dobiti email',
    'Email subject' => 'Predmet email-a',
    'Date' => 'Datum',
    'Add a comment log when moving the task between columns' => 'Dodaj komentar u dnevnik kada se pomjeri zadatak između kolona',
    'Move the task to another column when the category is changed' => 'Pomjeri zadatak u drugu kolonu kada je kategorija promijenjena',
    'Send a task by email to someone' => 'Pošalji zadatak nekome emailom',
    'Reopen a task' => 'Ponovo otvori zadatak',
    'Notification' => 'Obavještenja',
    '%s moved the task #%d to the first swimlane' => '%s je premjestio zadatak #%d u prvu swimlane traku',
    'Swimlane' => 'Swimlane traka',
    '%s moved the task %s to the first swimlane' => '%s je premjestio zadatak %s u prvi swimlane traku',
    '%s moved the task %s to the swimlane "%s"' => '%s je premjestio zadatak %s u swimlane traku "%s"',
    'This report contains all subtasks information for the given date range.' => 'Ovaj izvještaj sadržava sve informacije o pod-zadacima za dati period',
    'This report contains all tasks information for the given date range.' => 'Ovaj izvještaj sadržava sve informacije o zadacima u datom periodu',
    'Project activities for %s' => 'Aktivnosti projekta za %s',
    'view the board on Kanboard' => 'pregled ploče na Kanboard-u',
    'The task has been moved to the first swimlane' => 'Zadatak je premješten u prvu swimlane traku',
    'The task has been moved to another swimlane:' => 'Zadatak je premješten u drugu swimlane traku',
    'New title: %s' => 'Novi naslov: %s',
    'The task is not assigned anymore' => 'Zadatak nema više izvršioca',
    'New assignee: %s' => 'Novi izvršilac: %s',
    'There is no category now' => 'Sada nema kategorije',
    'New category: %s' => 'Nova kategorija: %s',
    'New color: %s' => 'Nova boja: %s',
    'New complexity: %d' => 'Nova složenost: %d',
    'The due date has been removed' => 'Datum završetka je ukloljen',
    'There is no description anymore' => 'Nema više opisa',
    'Recurrence settings has been modified' => 'Promijenjene postavke za ponavljajuće zadatke',
    'Time spent changed: %sh' => 'Utrošeno vrijeme je promijenjeno: %sh',
    'Time estimated changed: %sh' => 'Očekivano vrijeme je promijenjeno: %sh',
    'The field "%s" has been updated' => 'Polje "%s" je ažurirano',
    'The description has been modified:' => 'Promijenjen opis:',
    'Do you really want to close the task "%s" as well as all subtasks?' => 'Da li zaista želiš zatvoriti zadatak "%s" kao i sve pod-zadatke?',
    'I want to receive notifications for:' => 'Želim dobijati obavještenja za:',
    'All tasks' => 'Sve zadatke',
    'Only for tasks assigned to me' => 'Samo za zadatke na kojima sam izvršilac',
    'Only for tasks created by me' => 'Samo za zadatke koje sam ja napravio',
    'Only for tasks created by me and tasks assigned to me' => 'Samo za zadatke koje sam ja napravio i na kojima sam izvršilac',
    '%%Y-%%m-%%d' => '%%Y-%%m-%%d',
    'Total for all columns' => 'Ukupno za sve kolone',
    'You need at least 2 days of data to show the chart.' => 'Da bi se prikazao ovaj grafik potrebni su podaci iz najmanje posljednja dva dana.',
    '<15m' => '<15m',
    '<30m' => '<30m',
    'Stop timer' => 'Zaustavi tajmer',
    'Start timer' => 'Pokreni tajmer',
    'My activity stream' => 'Tok mojih aktivnosti',
    'Search tasks' => 'Pretraga zadataka',
    'Reset filters' => 'Vrati filtere na početno',
    'My tasks due tomorrow' => 'Moji zadaci koje treba završiti sutra',
    'Tasks due today' => 'Zadaci koje treba završiti danas',
    'Tasks due tomorrow' => 'Zadaci koje treba završiti sutra',
    'Tasks due yesterday' => 'Zadaci koje je trebalo završiti jučer',
    'Closed tasks' => 'Zatvoreni zadaci',
    'Open tasks' => 'Otvoreni zadaci',
    'Not assigned' => 'Bez izvršioca',
    'View advanced search syntax' => 'Vidi naprednu sintaksu pretrage',
    'Overview' => 'Opšti pregled',
    'Board/Calendar/List view' => 'Pregled Ploče/Kalendara/Liste',
    'Switch to the board view' => 'Promijeni da vidim ploču',
    'Switch to the list view' => 'Promijeni da vidim listu',
    'Go to the search/filter box' => 'Idi na kutiju s pretragom/filterima',
    'There is no activity yet.' => 'Još uvijek nema aktivnosti.',
    'No tasks found.' => 'Zadaci nisu pronađeni.',
    'Keyboard shortcut: "%s"' => 'Prečica tastature: "%s"',
    'List' => 'Lista',
    'Filter' => 'Filter',
    'Advanced search' => 'Napredna pretraga',
    'Example of query: ' => 'Primjer za upit: ',
    'Search by project: ' => 'Pretraga po projektu: ',
    'Search by column: ' => 'Pretraga po koloni: ',
    'Search by assignee: ' => 'Pretraga po izvršiocu: ',
    'Search by color: ' => 'Pretraga po boji: ',
    'Search by category: ' => 'Pretraga po kategoriji: ',
    'Search by description: ' => 'Pretraga po opisu: ',
    'Search by due date: ' => 'Pretraga po datumu završetka: ',
    'Average time spent in each column' => 'Prosjek utrošenog vrmena u svakoj koloni',
    'Average time spent' => 'Prosjek utrošenog vremena',
    'This chart shows the average time spent in each column for the last %d tasks.' => 'Ovaj grafik pokazuje prosjek utrošenog vremena u svakoj koloni za posljednjih %d zadataka.',
    'Average Lead and Cycle time' => 'Prosjek vremena upravljanja i vremenskog ciklusa',
    'Average lead time: ' => 'Prosjek vremena upravljanja',
    'Average cycle time: ' => 'Prosjek vremenskog ciklusa',
    'Cycle Time' => 'Vremenski ciklus',
    'Lead Time' => 'Vrijeme upravljanja',
    'This chart shows the average lead and cycle time for the last %d tasks over the time.' => 'Ovaj grafik pokazuje prosjek vremena vođenja i vremenskog ciklusa za posljednjih %d zadataka tokom vremena.',
    'Average time into each column' => 'Prosječno vrijeme u svakoj koloni',
    'Lead and cycle time' => 'Vrijeme vođenja i vremenski ciklus',
    'Lead time: ' => 'Vrijeme vođenja: ',
    'Cycle time: ' => 'Vremenski ciklus: ',
    'Time spent in each column' => 'Utrošeno vrijeme u svakoj koloni',
    'The lead time is the duration between the task creation and the completion.' => 'Vrijeme vođenja je vrijeme koje je proteklo između otvaranja i zatvaranja zadatka.',
    'The cycle time is the duration between the start date and the completion.' => 'Vremenski ciklus je vrijeme koje je proteklo između početka i završetka rada na zadatku.',
    'If the task is not closed the current time is used instead of the completion date.' => 'Ako zadatak nije zatvoren trenutno vrijeme je iskorišteno umjesto datuma završetka.',
    'Set the start date automatically' => 'Automatski postavi početno vrijeme',
    'Edit Authentication' => 'Uredi autentifikaciju',
    'Remote user' => 'Vanjski korisnik',
    'Remote users do not store their password in Kanboard database, examples: LDAP, Google and Github accounts.' => 'Vanjski korisnik ne čuva šifru u Kanboard bazi, npr: LDAP, Google i Github korisnički računi.',
    'If you check the box "Disallow login form", credentials entered in the login form will be ignored.' => 'Ako ste označili kvadratić "Zabrani prijavnu formu", unos pristupnih podataka u prijavnoj formi će biti ignorisan.',
    'Default task color' => 'Podrazumijevana boja zadatka',
    'This feature does not work with all browsers.' => 'Ovaj funkcionalnost ne radi na svim internet pretraživačima.',
    'There is no destination project available.' => 'Nema definisanog odredišta za projekat.',
    'Trigger automatically subtask time tracking' => 'Okidač za automatsko vremensko praćenje za pod-zadatke',
    'Include closed tasks in the cumulative flow diagram' => 'Obuhvati zatvorene zadatke u kumulativnom dijagramu toka',
    'Current swimlane: %s' => 'Trenutna swimlane traka: %s',
    'Current column: %s' => 'Trenutna kolona: %s',
    'Current category: %s' => 'Trenutna kategorija: %s',
    'no category' => 'bez kategorije',
    'Current assignee: %s' => 'Trenutni izvršilac: %s',
    'not assigned' => 'bez ivršioca',
    'Author:' => 'Autor:',
    'contributors' => 'saradnici',
    'License:' => 'Licenca:',
    'License' => 'Licenca',
    'Enter the text below' => 'Unesi tekst ispod',
    'Start date:' => 'Početno vrijeme:',
    'Due date:' => 'Vrijeme do kada treba završiti:',
    'People who are project managers' => 'Osobe koji su menadžeri projekta',
    'People who are project members' => 'Osobe koje su članovi projekta',
    'NOK - Norwegian Krone' => 'NOK - Norveška kruna',
    'Show this column' => 'Prikaži ovu kolonu',
    'Hide this column' => 'Sakrij ovu kolonu',
    'End date' => 'Datum završetka',
    'Users overview' => 'Opšti pregled korisnika',
    'Members' => 'Članovi',
    'Shared project' => 'Dijeljeni projekti',
    'Project managers' => 'Menadžeri projekta',
    'Projects list' => 'Lista projekata',
    'End date:' => 'Datum završetka:',
    'Change task color when using a specific task link' => 'Promijeni boju zadatka kada se koristi određena veza na zadatku',
    'Task link creation or modification' => 'Veza na zadatku je napravljena ili izmijenjena',
    'Milestone' => 'Prekretnica',
    'Reset the search/filter box' => 'Vrati na početno pretragu/filtere',
    'Documentation' => 'Dokumentacija',
    'Author' => 'Autor',
    'Version' => 'Verzija',
    'Plugins' => 'Dodaci',
    'There is no plugin loaded.' => 'Nema učitanih dodataka.',
    'My notifications' => 'Moja obavještenja',
    'Custom filters' => 'Prilagođeni filteri',
    'Your custom filter has been created successfully.' => 'Tvoj prilagođeni filter je uspješno napravljen.',
    'Unable to create your custom filter.' => 'Nemoguće napraviti prilagođeni filter.',
    'Custom filter removed successfully.' => 'Prilagođeni filter uspješno uklonjen.',
    'Unable to remove this custom filter.' => 'Nemoguće ukloniti prilagođeni filter.',
    'Edit custom filter' => 'Uredi prilagođeni filter',
    'Your custom filter has been updated successfully.' => 'Prilagođeni filter uspješno ažuriran.',
    'Unable to update custom filter.' => 'Nemoguće ažurirati prilagođeni filter',
    'Web' => 'Web',
    'New attachment on task #%d: %s' => 'Novi priložak na zadatku #%d: %s',
    'New comment on task #%d' => 'Novi komentar na zadatku #%d',
    'Comment updated on task #%d' => 'Ažuriran komentar na zadatku #%d',
    'New subtask on task #%d' => 'Novi pod-zadatak na zadatku #%d',
    'Subtask updated on task #%d' => 'Pod-zadatak ažuriran na zadatku #%d',
    'New task #%d: %s' => 'Novi zadatak #%d: %s',
    'Task updated #%d' => 'Zadatak ažuriran #%d',
    'Task #%d closed' => 'Zadatak #%d zatvoren',
    'Task #%d opened' => 'Zadatak #%d otvoren',
    'Column changed for task #%d' => 'Promijenjena kolona za zadatak #%d',
    'New position for task #%d' => 'Nova pozicija za zadatak #%d',
    'Swimlane changed for task #%d' => 'Swimlane traka promijenjena za zadatak #%d',
    'Assignee changed on task #%d' => 'Promijenjen izvršilac na zadatku #%d',
    '%d overdue tasks' => '%d zadataka kasni',
    'No notification.' => 'Nema novih obavještenja.',
    'Mark all as read' => 'Označi sve kao pročitano',
    'Mark as read' => 'Označi kao pročitano',
    'Total number of tasks in this column across all swimlanes' => 'Ukupan broj zadataka u ovoj koloni u svim swimlane trakama',
    'Collapse swimlane' => 'Skupi swimlane trake',
    'Expand swimlane' => 'Proširi swimlane trake',
    'Add a new filter' => 'Dodaj novi filter',
    'Share with all project members' => 'Podijeli sa svim članovima projekta',
    'Shared' => 'Podijeljeno',
    'Owner' => 'Vlasnik',
    'Unread notifications' => 'Nepročitana obavještenja',
    'Notification methods:' => 'Metode obavještenja:',
    'Unable to read your file' => 'Nemoguće pročitati datoteku',
    '%d task(s) have been imported successfully.' => '%d zadataka uspješno uvezeno.',
    'Nothing has been imported!' => 'Ništa nije uvezeno!',
    'Import users from CSV file' => 'Uvezi korisnike putem CSV datoteke',
    '%d user(s) have been imported successfully.' => '%d korisnika uspješno uvezeno.',
    'Comma' => 'Zarez',
    'Semi-colon' => 'Tačka-zarez',
    'Tab' => 'Tab',
    'Vertical bar' => 'Vertikalna traka',
    'Double Quote' => 'Dvostruki navodnici',
    'Single Quote' => 'Jednostruki navodnici',
    '%s attached a file to the task #%d' => '%s je dodao novu datoteku u zadatak %d',
    'There is no column or swimlane activated in your project!' => 'Nema kolone ili swimlane trake aktivirane za ovaj projekat!',
    'Append filter (instead of replacement)' => 'Dodaj filter (umjesto zamjene postojećeg)',
    'Append/Replace' => 'Dodaj/Zamijeni',
    'Append' => 'Dodaj',
    'Replace' => 'Zamijeni',
    'Import' => 'Uvoz',
    'Change sorting' => 'Promijeni sortiranje',
    'Tasks Importation' => 'Uvoz zadataka',
    'Delimiter' => 'Djelilac',
    'Enclosure' => 'Prilog',
    'CSV File' => 'CSV File',
    'Instructions' => 'Uputstva',
    'Your file must use the predefined CSV format' => 'File mora biti predefinisani CSV format',
    'Your file must be encoded in UTF-8' => 'File mora biti u UTF-8 kodu',
    'The first row must be the header' => 'Prvi red mora biti zaglavlje',
    'Duplicates are not verified for you' => 'Dupliciranja neće biti provjeravana (to ćeš morati uraditi ručno)',
    'The due date must use the ISO format: YYYY-MM-DD' => 'Datum do kog se treba izvršiti mora biti u ISO formatu: GGGG-MM-DD',
    'Download CSV template' => 'Preuzmi CSV šablon',
    'No external integration registered.' => 'Nema registrovanih vanjskih integracija.',
    'Duplicates are not imported' => 'Duplikati nisu uvezeni',
    'Usernames must be lowercase and unique' => 'Korisničko ime mora biti malim slovima i jedinstveno',
    'Passwords will be encrypted if present' => 'Šifra će biti kriptovana',
    '%s attached a new file to the task %s' => '%s je dodao novu datoteku u zadatak %s',
    'Link type' => 'Tip veze',
    'Assign automatically a category based on a link' => 'Automatsko pridruživanje kategorije bazirano na vezi',
    'BAM - Konvertible Mark' => 'BAM - Konvertibilna marka',
    'Assignee Username' => 'Pridruži korisničko ime',
    'Assignee Name' => 'Pridruži ime',
    'Groups' => 'Grupe',
    'Members of %s' => 'Članovi %s',
    'New group' => 'Nova grupa',
    'Group created successfully.' => 'Grupa uspješno kreirana.',
    'Unable to create your group.' => 'Nemoguće kreirati grupu.',
    'Edit group' => 'Uredi grupu',
    'Group updated successfully.' => 'Grupa uspješno ažurirana.',
    'Unable to update your group.' => 'Nemoguće ažurirati grupu',
    'Add group member to "%s"' => 'Dodaj člana grupe u ""%s"',
    'Group member added successfully.' => 'Uspješno dodan član grupe.',
    'Unable to add group member.' => 'Nemoguće dodati člana grupe.',
    'Remove user from group "%s"' => 'Ukloni korisnika iz grupe "%s"',
    'User removed successfully from this group.' => 'Korisnik uspješno uklonjen iz grupe.',
    'Unable to remove this user from the group.' => 'Nemoguće ukloniti korisnika iz grupe.',
    'Remove group' => 'Ukloni grupu',
    'Group removed successfully.' => 'Grupa uspješno uklonjena.',
    'Unable to remove this group.' => 'Nemoguće ukloniti grupu.',
    'Project Permissions' => 'Prava na projektu',
    'Manager' => 'Menadžer',
    'Project Manager' => 'Menadžer projekta',
    'Project Member' => 'Član projekta',
    'Project Viewer' => 'Preglednik projekta',
    'Your account is locked for %d minutes' => 'Tvoj korisnički račun je zaključan za narednih %d minuta',
    'Invalid captcha' => 'Pogrešna captcha',
    'The name must be unique' => 'Ime mora biti jedinstveno',
    'View all groups' => 'Pregledaj sve grupe',
    'There is no user available.' => 'Trenutno nema dostupnih korisnika.',
    'Do you really want to remove the user "%s" from the group "%s"?' => 'Da li zaista želiš ukloniti korisnika "%s" iz grupe "%s"?',
    'There is no group.' => 'Trenutno nema grupa.',
    'Add group member' => 'Dodaj člana grupe',
    'Do you really want to remove this group: "%s"?' => 'Da li zaista želiš ukloniti ovu grupu: "%s"?',
    'There is no user in this group.' => 'Trenutno nema korisnika u grupi.',
    'Permissions' => 'Prava',
    'Allowed Users' => 'Dozvoljeni korisnici',
    'No specific user has been allowed.' => 'Nema korisnika sa specijalnim dozvolama.',
    'Role' => 'Uloge',
    'Enter user name...' => 'Unesi korisničko ime...',
    'Allowed Groups' => 'Dozvoljene grupe',
    'No group has been allowed.' => 'Nema grupa sa specijalnim dozvolama.',
    'Group' => 'Grupa',
    'Group Name' => 'Ime grupe',
    'Enter group name...' => 'Unesi ime grupe...',
    'Role:' => 'Uloga:',
    'Project members' => 'Članovi projekta',
    '%s mentioned you in the task #%d' => '%s te spomenuo u zadatku #%d',
    '%s mentioned you in a comment on the task #%d' => '%s te spomenuo u komentaru zadatka #%d',
    'You were mentioned in the task #%d' => 'Spomenut si u zadatku #%d',
    'You were mentioned in a comment on the task #%d' => 'Spomenut si u komentaru zadatka #%d',
    'Estimated hours: ' => 'Očekivani sati:',
    'Actual hours: ' => 'Aktuelni sati:',
    'Hours Spent' => 'Utrošeni sati:',
    'Hours Estimated' => 'Očekivani sati',
    'Estimated Time' => 'Očekivano vrijeme',
    'Actual Time' => 'Aktuelno vrijeme',
    'Estimated vs actual time' => 'Očekivano nasuprot aktuelnog vremena',
    'RUB - Russian Ruble' => 'RUB - Ruski rubij',
    'Assign the task to the person who does the action when the column is changed' => 'Dodijeli zadatak osobi koja izvrši akciju promjene kolone',
    'Close a task in a specific column' => 'Zatvori zadatak u određenoj koloni',
    'Time-based One-time Password Algorithm' => 'Vremenski bazirani One-time Algoritam šifri',
    'Two-Factor Provider: ' => '"Dva-faktora" provajder: ',
    'Disable two-factor authentication' => 'Onemogući "Dva-faktora" autentifikaciju',
    'Enable two-factor authentication' => 'Omogući "Dva-faktora" autentifikaciju',
    'There is no integration registered at the moment.' => 'Trenutno nema registrovanih integracija.',
    'Password Reset for Kanboard' => 'Promjena šifre za Kanboard',
    'Forgot password?' => 'Ne mogu da se sjetim šifre?',
    'Enable "Forget Password"' => 'Omogući "Ne mogu da se sjetim šifre"',
    'Password Reset' => 'Promijena šifre',
    'New password' => 'Nova šifra',
    'Change Password' => 'Promijeni šifru',
    'To reset your password click on this link:' => 'Da bi promijenio šifru klikni na ovaj link:',
    'Last Password Reset' => 'Posljednja promjena šifre',
    'The password has never been reinitialized.' => 'Šifra nije nikada mijenjena.',
    'Creation' => 'Napravljena',
    'Expiration' => 'Ističe',
    'Password reset history' => 'Hitorija promjena šifri',
    'All tasks of the column "%s" and the swimlane "%s" have been closed successfully.' => 'Svi zadaci kolone "%s" i swimlane-a "%s" uspješno su zatvoreni.',
    'Do you really want to close all tasks of this column?' => 'Da li zaista želiš zatvoriti sve zadatke ove kolone?',
    '%d task(s) in the column "%s" and the swimlane "%s" will be closed.' => '%d zadatak(ci) u koloni "%s" i swimlane-u "%s" će biti zatvoreni.',
    'Close all tasks in this column and this swimlane' => 'Zatvori sve zadatke ove kolone',
    'No plugin has registered a project notification method. You can still configure individual notifications in your user profile.' => 'Nema posebnog Dodatka za obavještenja. Još uvijek možeš koristiti individualne postavke obavještenja na svom profilu.',
    'My dashboard' => 'Moj panel',
    'My profile' => 'Moj profil',
    'Project owner: ' => 'Vlasnik projekta: ',
    'The project identifier is optional and must be alphanumeric, example: MYPROJECT.' => 'Identifikator projekta je opcionalan i mora biti alfanumerički, na primjer: MOJPROJEKAT.',
    'Project owner' => 'Vlasnik projekta',
    'Personal projects do not have users and groups management.' => 'Privatni projekti ne mogu imati korisnike ili grupe korisnika.',
    'There is no project member.' => 'Nema članova projekta.',
    'Priority' => 'Prioritet',
    'Task priority' => 'Prioritet zadatka',
    'General' => 'Opšte',
    'Dates' => 'Datumi',
    'Default priority' => 'Podrazumijevani prioritet',
    'Lowest priority' => 'Najmanji prioritet',
    'Highest priority' => 'Najveći prioritet',
    'Close a task when there is no activity' => 'Zatvori zadatak kada nema aktivnosti',
    'Duration in days' => 'Dužina trajanja u danima',
    'Send email when there is no activity on a task' => 'Pošalji email kada nema aktivnosti na zadatku',
    'Unable to fetch link information.' => 'Ne mogu da pribavim informacije o vezi.',
    'Daily background job for tasks' => 'Dnevni pozadinski poslovi na zadacima',
    'Auto' => 'Automatski',
    'Related' => 'Povezani',
    'Attachment' => 'Dodijeljeni',
    'Title not found' => 'Bez naslova',
    'Web Link' => 'Web veza',
    'External links' => 'Vanjska veza',
    'Add external link' => 'Dodaj vanjsku vezu',
    'Type' => 'Vrsta',
    'Dependency' => 'Zavisnost',
    'Add internal link' => 'Dodaj unutrašnju vezu',
    'Add a new external link' => 'Dodaj novu vanjsku vezu',
    'Edit external link' => 'Uredi vanjsku vezu',
    'External link' => 'Vanjska veza',
    'Copy and paste your link here...' => 'Kopiraj i zalijepi svoju vezu ovdje...',
    'URL' => 'URL',
    'Internal links' => 'Unutrašnje veze',
    'Assign to me' => 'Dodijeli meni',
    'Me' => 'Za mene',
    'Do not duplicate anything' => 'Ništa ne dupliciraj',
    'Projects management' => 'Menadžment projekata',
    'Users management' => 'Menadžment korisnika',
    'Groups management' => 'Menadžment grupa',
    'Create from another project' => 'Napravi iz drugog projekta',
    'open' => 'otvoreno',
    'closed' => 'zatvoreno',
    'Priority:' => 'Prioritet:',
    'Reference:' => 'Preporuka:',
    'Complexity:' => 'Složenost:',
    'Swimlane:' => 'Swimlane:',
    'Column:' => 'Kolona:',
    'Position:' => 'Pozicija:',
    'Creator:' => 'Kreator:',
    'Time estimated:' => 'Očekivano vrijeme:',
    '%s hours' => '%s sati',
    'Time spent:' => 'Utrošeno vrijeme:',
    'Created:' => 'Kreirao:',
    'Modified:' => 'Uredio:',
    'Completed:' => 'Završio:',
    'Started:' => 'Početo:',
    'Moved:' => 'Pomjereno:',
    'Task #%d' => 'Zadatak #%d',
    'Time format' => 'Format za vrijeme',
    'Start date: ' => 'Početni datum:',
    'End date: ' => 'Krajnji datum:',
    'New due date: ' => 'Novi datum očekivanja:',
    'Start date changed: ' => 'Početni datum promijenjen:',
    'Disable personal projects' => 'Onemogući privatne projekte',
    'Do you really want to remove this custom filter: "%s"?' => 'Da li zaista želiš ukloniti ovaj prilagođeni filter "%s"?',
    'Remove a custom filter' => 'Ukloni prilagođeni filter',
    'User activated successfully.' => 'Korisnik uspješno aktiviran.',
    'Unable to enable this user.' => 'Nemoguće omogućiti ovog korisnika.',
    'User disabled successfully.' => 'Korisnik uspješno onemogućen.',
    'Unable to disable this user.' => 'Nemoguće onemogućiti ovog korisnika.',
    'All files have been uploaded successfully.' => 'Sve datoteke su uspješno dodane.',
    'The maximum allowed file size is %sB.' => 'Maksimalna dozvoljena veličina datoteke je %sB.',
    'Drag and drop your files here' => 'Povuci i spusti svoje datoteke ovdje',
    'choose files' => 'izaberi datoteke',
    'View profile' => 'Pregledaj profil',
    'Two Factor' => 'Dva faktora',
    'Disable user' => 'Onemogući korisnika',
    'Do you really want to disable this user: "%s"?' => 'Da li zaista želiš onemogućiti ovog korisnika: "%s"?',
    'Enable user' => 'Omogući korisnika',
    'Do you really want to enable this user: "%s"?' => 'Da li zaista želiš omogućiti ovog korisnika: "%s"?',
    'Download' => 'Preuzeto',
    'Uploaded: %s' => 'Dodano: %s',
    'Size: %s' => 'Veličina: %s',
    'Uploaded by %s' => 'Dodao %s',
    'Filename' => 'Ime datoteke',
    'Size' => 'Veličina',
    'Column created successfully.' => 'Kolona uspješno napravljena.',
    'Another column with the same name exists in the project' => 'Već postoji kolona s istim imenom u ovom projektu.',
    'Default filters' => 'Podrazumijevani filteri',
    'Your board doesn\'t have any columns!' => 'Tvoj panel nema ni jednu kolonu!',
    'Change column position' => 'Promijeni poziciju kolone',
    'Switch to the project overview' => 'Promijeni u pregled projekta',
    'User filters' => 'Korisnički filteri',
    'Category filters' => 'Kategorija filtera',
    'Upload a file' => 'Priloži datoteku',
    'View file' => 'Pregled datoteke',
    'Last activity' => 'Posljednja aktivnost',
    'Change subtask position' => 'Promijeni poziciju pod-zadatka',
    'This value must be greater than %d' => 'Ova vrijednost mora biti veća od %d',
    'Another swimlane with the same name exists in the project' => 'Već postoji swimlane sa istim imenom u ovom projektu',
    'Example: https://example.kanboard.org/ (used to generate absolute URLs)' => 'Na primjer: https://example.kanboard.org/ (koristi se za pravljenje apsolutnog URL-a)',
    'Actions duplicated successfully.' => 'Akcije uspješno duplicirane.',
    'Unable to duplicate actions.' => 'Nemoguće duplicirati akcije.',
    'Add a new action' => 'Dodaj novu akciju',
    'Import from another project' => 'Uvezi iz drugog projekta',
    'There is no action at the moment.' => 'Trenutno nema akcija.',
    'Import actions from another project' => 'Uvezi akcije iz drugog projekta',
    'There is no available project.' => 'Trenutno nema dostupnih projekata.',
    'Local File' => 'Lokalna datoteka',
    'Configuration' => 'Konfiguracija',
    'PHP version:' => 'Verzija PHP-a:',
    'PHP SAPI:' => 'Verzija SAPI-a:',
    'OS version:' => 'Verzija OS-a:',
    'Database version:' => 'Verzija baze podataka:',
    'Browser:' => 'Pretraživač:',
    'Task view' => 'Pregled zadatka',
    'Edit task' => 'Uredi zadatak',
    'Edit description' => 'Uredi opis',
    'New internal link' => 'Nova unutrašnja veza',
    'Display list of keyboard shortcuts' => 'Prikaži listu prečica na tastaturi',
    'Avatar' => 'Avatar',
    'Upload my avatar image' => 'Dodaj sliku za moj avatar',
    'Remove my image' => 'Ukloni moju sliku',
    'The OAuth2 state parameter is invalid' => 'OAuth2 status parametar nije validan',
    'User not found.' => 'Korisnik nije pronađen.',
    'Search in activity stream' => 'Pretraži aktivnosti',
    'My activities' => 'Moje aktivnosti',
    'Activity until yesterday' => 'Aktivnosti do jučer',
    'Activity until today' => 'Aktivnosti do danas',
    'Search by creator: ' => 'Pretraga po kreatoru: ',
    'Search by creation date: ' => 'Pretraga po datumu kreiranja: ',
    'Search by task status: ' => 'Pretraga po statusu zadatka: ',
    'Search by task title: ' => 'Pretraga po naslovu zadatka: ',
    'Activity stream search' => 'Pretraga aktivnosti',
    'Projects where "%s" is manager' => 'Projekti gdje je "%s" menadžer',
    'Projects where "%s" is member' => 'Projekti gdje je "%s" član',
    'Open tasks assigned to "%s"' => 'Otvoreni zadaci dodijeljeni "%s"',
    'Closed tasks assigned to "%s"' => 'Zatvoreni zadaci dodijeljeni "%s"',
    'Assign automatically a color based on a priority' => 'Dodijeli boju automatski bazirano na prioritetu',
    'Overdue tasks for the project(s) "%s"' => 'Zadaci u kašnjenju za projekat(te) "%s"',
    'Upload files' => 'Priloži dokumente',
    'Installed Plugins' => 'Instalirani dodaci',
    'Plugin Directory' => 'Direktorij dodataka',
    'Plugin installed successfully.' => 'Dodatak je uspješno instaliran.',
    'Plugin updated successfully.' => 'Dodatak je uspješno ažuriran.',
    'Plugin removed successfully.' => 'Dodatak uspješno uklonjen.',
    'Subtask converted to task successfully.' => 'Pod-zadatak uspješno pretvoren u zadatak.',
    'Unable to convert the subtask.' => 'Nemoguće pretvoriti pod-zadatak.',
    'Unable to extract plugin archive.' => 'Nemoguće otpakovati arhivu dodatka.',
    'Plugin not found.' => 'Dodatak nije pronađen.',
    'You don\'t have the permission to remove this plugin.' => 'Nemate prava za uklanjanje ovog dodatka.',
    'Unable to download plugin archive.' => 'Nemoguće preuzeti arhivu dodatka.',
    'Unable to write temporary file for plugin.' => 'Nemoguće zapisati privremenu datoteku za dodatak.',
    'Unable to open plugin archive.' => 'Nemoguće otvoriti arhivu dodatka.',
    'There is no file in the plugin archive.' => 'Nema datoteke u arhivi dodatka.',
    'Create tasks in bulk' => 'Kreiranje zadataka u rinfuzi',
    'Your Kanboard instance is not configured to install plugins from the user interface.' => 'Ova Kanboard nije konfigurisan tako da podržava instalaciju dodataka kroz korisničko okruženje.',
    'There is no plugin available.' => 'Dodaci nisu dostupni.',
    'Install' => 'Instaliraj',
    'Update' => 'Ažuriraj',
    'Up to date' => 'Ažurirano',
    'Not available' => 'Nije dostupno',
    'Remove plugin' => 'Ukloni dodatak',
    'Do you really want to remove this plugin: "%s"?' => 'Da li zaista želiš ukloniti ovaj dodatak: "%s"?',
    'Uninstall' => 'Deinstaliraj',
    'Listing' => 'Spisak',
    'Metadata' => 'Metadata',
    'Manage projects' => 'Upravljanje projektima',
    'Convert to task' => 'Pretvori u zadatak',
    'Convert sub-task to task' => 'Pretvori pod-zadatak u zadatak',
    'Do you really want to convert this sub-task to a task?' => 'Da li zaista želiš pretvoriti pod-zadatak u zadatak?',
    'My task title' => 'Naslov zadatka',
    'Enter one task by line.' => 'Unesi jedan zadatak po liniji.',
    'Number of failed login:' => 'Broj neuspješnih prijava:',
    'Account locked until:' => 'Korisnički račun zaključan do:',
    'Email settings' => 'Postavke email-a',
    'Email sender address' => 'Email adresa pošiljaoca',
    'Email transport' => 'Saobraćaj emil-a',
    'Webhook token' => 'Webhook token',
    'Project tags management' => 'Upravljanje oznakama projekta',
    'Tag created successfully.' => 'Oznaka uspješno kreirana.',
    'Unable to create this tag.' => 'Nemoguće kreirati oznaku.',
    'Tag updated successfully.' => 'Oznaka uspješno ažurirana.',
    'Unable to update this tag.' => 'Nemoguće ažurirati ovu oznaku.',
    'Tag removed successfully.' => 'Oznaka uspješno uklonjena.',
    'Unable to remove this tag.' => 'Nemoguće ukloniti ovu oznaku.',
    'Global tags management' => 'Upravljanje opštih oznaka.',
    'Tags' => 'Oznake',
    'Tags management' => 'Upravljanje oznakama',
    'Add new tag' => 'Dodaj novu oznaku',
    'Edit a tag' => 'Uredi oznaku',
    'Project tags' => 'Oznake projekta',
    'There is no specific tag for this project at the moment.' => 'Trenutno nema oznaka za ovaj projekat.',
    'Tag' => 'Oznaka',
    'Remove a tag' => 'Ukloni oznaku',
    'Do you really want to remove this tag: "%s"?' => 'Da li zaista želiš ukloniti ovu oznaku: "%s"?',
    'Global tags' => 'Opšte oznake',
    'There is no global tag at the moment.' => 'Trenutno nema opštih oznaka.',
    'This field cannot be empty' => 'Ovo polje ne može biti prazno',
    'Close a task when there is no activity in a specific column' => 'Zatvori zadatak kada nema aktivnosti u odabranoj koloni',
    '%s removed a subtask for the task #%d' => '%s je uklonio pod-zadatak za zadatak #%d',
    '%s removed a comment on the task #%d' => '%s je uklonio komentar na zadatku #%d',
    'Comment removed on task #%d' => 'Komentar ukloljen na zadatku #%d',
    'Subtask removed on task #%d' => 'Pod-zadatak ukloljn na zadatku #%d',
    'Hide tasks in this column in the dashboard' => 'Skrij zadatke u koloni na radnoj ploči',
    '%s removed a comment on the task %s' => '%s je uklonio komentar za zadatak %s',
    '%s removed a subtask for the task %s' => '%s je uklonio pod-zadatak za zadatak %s',
    'Comment removed' => 'Komentar uklonjen',
    'Subtask removed' => 'Pod-zadatak uklonjen',
    '%s set a new internal link for the task #%d' => '%s je dodao novu unutrašnju vezu za zadatak #%d',
    '%s removed an internal link for the task #%d' => '%s je uklonio unutrašnju vezu za zadatak #%d',
    'A new internal link for the task #%d has been defined' => 'Nova unutrašnja veza za zadatak #%d je definisana',
    'Internal link removed for the task #%d' => 'Unutrašnja veza je uklonjena za zadatak #%d',
    '%s set a new internal link for the task %s' => '%s je dodao novu unutrašnju vezu za zadatak %s',
    '%s removed an internal link for the task %s' => '%s je uklonio unutrašnju vezu za zadatak %s',
    'Automatically set the due date on task creation' => 'Automatski dodaj datum roka izvršenja na kreiranom zadatku',
    'Move the task to another column when closed' => 'Pomjeri zadatak u drugu kolonu kada je zatvoren',
    'Move the task to another column when not moved during a given period' => 'Pomjeri zadatak u drugu kolonu kada nema pomijeranja za zadati period',
    'Dashboard for %s' => 'Radna ploča za %s',
    'Tasks overview for %s' => 'Pregled zadataka za %s',
    'Subtasks overview for %s' => 'Pregled pod-zadataka za %s',
    'Projects overview for %s' => 'Pregled projekata za %s',
    'Activity stream for %s' => 'Tok aktivnosti za %s',
    'Assign a color when the task is moved to a specific swimlane' => 'Dodijeli boju kada je zadatak pomjeren u određenu swimlane traku',
    'Assign a priority when the task is moved to a specific swimlane' => 'Dodijeli prioritet kada je zadatak pomjeren u određenu swimlane traku',
    'User unlocked successfully.' => 'Korisnik je uspješno otključan.',
    'Unable to unlock the user.' => 'Nemoguće otključati korisnika.',
    'Move a task to another swimlane' => 'Pomjeri zadatak u drugu swimlane traku',
    'Creator Name' => 'Ime kreatora',
    'Time spent and estimated' => 'Utrošeno i očekivano vrijeme',
    'Move position' => 'Mjesto pomijeranja',
    'Move task to another position on the board' => 'Pomjeri zadataka na drugo mjesto na radnoj ploči',
    'Insert before this task' => 'Umetni prije ovog zadatka',
    'Insert after this task' => 'Umetni poslije ovog zadatka',
    'Unlock this user' => 'Otključaj ovog korisnika',
    'Custom Project Roles' => 'Prilagođne uloge projekta',
    'Add a new custom role' => 'Dodaj novu prilagođenu ulogu',
    'Restrictions for the role "%s"' => 'Ograničenja za ulogu "%s"',
    'Add a new project restriction' => 'Dodaj nova ograničenja na projektu',
    'Add a new drag and drop restriction' => 'Dodaj nova "prevuci i spusti" ograničenja',
    'Add a new column restriction' => 'Dodaj nova ograničenja za kolonu',
    'Edit this role' => 'Uredi ovu ulogu',
    'Remove this role' => 'Ukloni ovu ulogu',
    'There is no restriction for this role.' => 'Nema ograničenja za ovu ulogu.',
    'Only moving task between those columns is permitted' => 'Samo između ovih kolona je dozvoljeno pomijeranje',
    'Close a task in a specific column when not moved during a given period' => 'Zatvori zadatak u odabranoj koloni kada nema pomijeranja za zadati period',
    'Edit columns' => 'Uredi kolone',
    'The column restriction has been created successfully.' => 'Ograničenja za kolonu su uspješno kreirana.',
    'Unable to create this column restriction.' => 'Nemoguće kreirati ograničenja za kolonu.',
    'Column restriction removed successfully.' => 'Ograničenja za kolonu su uspješno uklonjena.',
    'Unable to remove this restriction.' => 'Nemoguće ukloniti ovo ograničenje.',
    'Your custom project role has been created successfully.' => 'Tvoja prilagođena uloga na projekatu je uspješno kreirana.',
    'Unable to create custom project role.' => 'Nemoguće kreirati prilagođenu ulogu na projektu.',
    'Your custom project role has been updated successfully.' => 'Tvoja prilagođena uloga na projekatu je uspješno ažurirana.',
    'Unable to update custom project role.' => 'Nemoguće ažurirati prilagođenu ulogu na projektu.',
    'Custom project role removed successfully.' => 'Prilagođena uloga na projektu uspješno uklonjena.',
    'Unable to remove this project role.' => 'Nemoguće ukloniti ovu ulogu na projektu.',
    'The project restriction has been created successfully.' => 'Ograničenja na projektu uspješno kreirana.',
    'Unable to create this project restriction.' => 'Nemoguće kreirati ovo ograničenje na projektu.',
    'Project restriction removed successfully.' => 'Ograničenje na projektu uspješno uklonjeno.',
    'You cannot create tasks in this column.' => 'Ne možete kreirati zadatak u ovoj koloni.',
    'Task creation is permitted for this column' => 'Kreiranje zadatka u ovoj koloni je zabranjeno',
    'Closing or opening a task is permitted for this column' => 'Zatvaranje ili otvaranje zadatka u ovoj koloni je zabranjeno',
    'Task creation is blocked for this column' => 'Kreiranje zadatka je onemogućeno za ovu kolonu',
    'Closing or opening a task is blocked for this column' => 'Zatvaranje ili otvaranje zadatka u ovoj koloni je onemogućeno',
    'Task creation is not permitted' => 'Kreiranje zadatka nije dozvoljeno',
    'Closing or opening a task is not permitted' => 'Zatvarnaje ili otvaranje zadatka nije dozvoljeno',
    'New drag and drop restriction for the role "%s"' => 'Novo "prevuci i spusti" ograničenje za ulogu "%s"',
    'People belonging to this role will be able to move tasks only between the source and the destination column.' => 'Osobe kojima se dodijeli ova uloga će biti u mogućnosti pomijerati zadatke samo imeđu izvorne i odredišne kolone.',
    'Remove a column restriction' => 'Ukloni ograničenje za kolonu',
    'Do you really want to remove this column restriction: "%s" to "%s"?' => 'Da li zaista želiš uklonit ovo ograničenje za kolonu: "%s" u "%s"?',
    'New column restriction for the role "%s"' => 'Novo ograničenje za kolonu za ulogu "%s"',
    'Rule' => 'Uloga',
    'Do you really want to remove this column restriction?' => 'Da li zaista želiš ukloniti ovo ograničenje za kolonu?',
    'Custom roles' => 'Prilagođene uloge',
    'New custom project role' => 'Nova prilagođena uloga za projekat',
    'Edit custom project role' => 'Uredi prilagođenu ulogu za projekat',
    'Remove a custom role' => 'Ukloni prilagođenu ulogu',
    'Do you really want to remove this custom role: "%s"? All people assigned to this role will become project member.' => 'Da li zaista želiš ukloniti ovu prilagođenu ulogu: "%s"? Sve osobe kojima je dodijeljena ova uloga će postati članovi projekta.',
    'There is no custom role for this project.' => 'Nema prilagođenih uloga za ovaj projekat.',
    'New project restriction for the role "%s"' => 'Novo ograničenje na projektu za ulogu "%s"',
    'Restriction' => 'Ograničenje',
    'Remove a project restriction' => 'Ukloni ograničenje na projektu',
    'Do you really want to remove this project restriction: "%s"?' => 'Da li zaista želiš ukloniti ovo ograničenje na projektu: "%s"?',
    'Duplicate to multiple projects' => 'Dupliciraj u više projekata',
    'This field is required' => 'Ovo polje je obavezno',
    'Moving a task is not permitted' => 'Pomijeranje zadatka nije dozvoljeno',
    'This value must be in the range %d to %d' => 'Ova vrijednost mora biti u rasponu od %d do %d',
    'You are not allowed to move this task.' => 'Nemaš dozvolu za pomijeranje ovog zadatka.',
    'API User Access' => 'API User Access',
    'Preview' => 'Pregled',
    'Write' => 'Piši',
    'Write your text in Markdown' => 'Upiši tekst u Markdown',
    'No personal API access token registered.' => 'Nema registrovanog ličnog pristupnog API tokena',
    'Your personal API access token is "%s"' => 'Tvoj lični pristupni API token je: "%s"',
    'Remove your token' => 'Ukloni svoj token',
    'Generate a new token' => 'Generiši novi token',
    'Showing %d-%d of %d' => 'Prikaži %d-%d od %d',
    'Outgoing Emails' => 'Izlazni email-ovi',
    'Add or change currency rate' => 'Dodaj ili izmijeni odnos valuta',
    'Reference currency: %s' => 'Referentna valuta: %s',
    'Add custom filters' => 'Dodaj prilagođene filtere',
    'Export' => 'Izvezi',
    'Add link label' => 'Dodaj etiketu na vezu',
    'Incompatible Plugins' => 'Nekompatibilni dodaci',
    'Compatibility' => 'Kompatibilnost',
    'Permissions and ownership' => 'Dozvole i vlasništvo',
    'Priorities' => 'Prioriteti',
    'Close this window' => 'Zatvori ovaj pendžer',
    'Unable to upload this file.' => 'Nemoguće dodati ovu datoteku.',
    'Import tasks' => 'Uvezi zadatke.',
    'Choose a project' => 'Izaberi projekat',
    'Profile' => 'Profil',
    'Application role' => 'Uloga na aplikaciji',
    '%d invitations were sent.' => 'Poslano %d pozivnica.',
    '%d invitation was sent.' => 'Poslana %d pozivnica.',
    'Unable to create this user.' => 'Nemoguće kreirati ovog korisnika.',
    'Kanboard Invitation' => 'Kanboard Pozivnica',
    'Visible on dashboard' => 'Vidljivo na radnoj ploči',
    'Created at:' => 'Kreirao:',
    'Updated at:' => 'Ažurirao:',
    'There is no custom filter.' => 'Nema prilagođenih filtera.',
    'New User' => 'Novi korisnik',
    'Authentication' => 'Autentikacija',
    'If checked, this user will use a third-party system for authentication.' => 'Ako je označeno, ovaj korisnik će koristiti "treću stranu" za autentikaciju.',
    'The password is necessary only for local users.' => 'Šifra je neophodna samo za lokalne korisnike.',
    'You have been invited to register on Kanboard.' => 'Pozvan si da se registruješ na Kanboard.',
    'Click here to join your team' => 'Klikni ovdje da se pridružiš timu',
    'Invite people' => 'Pozovi ljude',
    'Emails' => 'Email-ovi',
    'Enter one email address by line.' => 'Unesi jednu email adresu po redu.',
    'Add these people to this project' => 'Dodaj ove ljude u ovaj projekat',
    'Add this person to this project' => 'Dodaj ovu osobu u ovaj projekat',
    'Sign-up' => 'Registracija',
    'Credentials' => 'Pristupni podaci',
    'New user' => 'Novi korisnik',
    'This username is already taken' => 'Ovo korisničko ime je zauzeto',
    'Your profile must have a valid email address.' => 'Profil mora imati validnu email adresu.',
    'TRL - Turkish Lira' => 'TRL - Turska Lira',
    'The project email is optional and could be used by several plugins.' => 'Email projekta je prizvoljan i može biti korišten od strane dodataka.',
    'The project email must be unique across all projects' => 'Email projekta mora biti jedinstven za svaki projekat',
    'The email configuration has been disabled by the administrator.' => 'Uređivanje email-a je onemogućeno od strane administratora.',
    'Close this project' => 'Zatvori ovaj projekat',
    'Open this project' => 'Otvori ovaj projekat',
    'Close a project' => 'Zatvori projekat',
    'Do you really want to close this project: "%s"?' => 'Da li zaista želiš zatvoriti projekat: "%s"?',
    'Reopen a project' => 'Ponovo otvori projekat',
    'Do you really want to reopen this project: "%s"?' => 'Da li zaista želiš ponovo otvoriti projekat: "%s"?',
    'This project is open' => 'Ovaj projekat je otvoren',
    'This project is closed' => 'Ovaj projekat je zatvoren',
    'Unable to upload files, check the permissions of your data folder.' => 'Nemoguće priložiti datoteke, provjeri prava na "data" direktoriju na serveru.',
    'Another category with the same name exists in this project' => 'Kategorija sa ovim imenom već postoji na ovom projektu',
    'Comment sent by email successfully.' => 'Komentar je uspješno poslan email-om.',
    'Sent by email to "%s" (%s)' => 'Pošalji email-om "%s" (%s)',
    'Unable to read uploaded file.' => 'Nemoguće pročitati dodanu datoteku.',
    'Database uploaded successfully.' => 'Baza podataka je uspješno dodana.',
    'Task sent by email successfully.' => 'Zadatak je uspješno poslan email-om.',
    'There is no category in this project.' => 'Nema kategorija u ovom projektu.',
    'Send by email' => 'Pošalji email-om',
    'Create and send a comment by email' => 'Kreiraj i pošalji komentar email-om',
    'Subject' => 'Predmet',
    'Upload the database' => 'Priloži u bazu podataka',
    'You could upload the previously downloaded Sqlite database (Gzip format).' => 'Možeš priložiti prethodno preuzetu Sqlite bazu podataka (Gzip format).',
    'Database file' => 'Datoteka baze podataka',
    'Upload' => 'Priloži',
    'Your project must have at least one active swimlane.' => 'Projekat mora imati barem jednu aktivnu swimlane traku.',
    'Project: %s' => 'Projekat: %s',
    'Automatic action not found: "%s"' => 'Automatska akcija nije pronađena: "%s"',
    '%d projects' => '%d projekata',
    '%d project' => '%d projekat',
    'There is no project.' => 'Ovo nije projekat.',
    'Sort' => 'Sortiraj',
    'Project ID' => 'ID projekta',
    'Project name' => 'Naziv projekta',
    'Public' => 'Javno',
    'Personal' => 'Privatno',
    '%d tasks' => '%d zadataka',
    '%d task' => '%d zadatak',
    'Task ID' => 'ID zadatka',
    'Assign automatically a color when due date is expired' => 'Automatski dodaj boju kada je krajnje vrijeme izvršenja isteklo',
    'Total score in this column across all swimlanes' => 'Ukupni rezultat u ovoj koloni za sve swimlane trake',
    'HRK - Kuna' => 'HRK - Hrvatska Kuna',
    'ARS - Argentine Peso' => 'ARS - Argentinski pezo',
    'COP - Colombian Peso' => 'COP - Kolumbijski pezo',
    '%d groups' => '%d grupa',
    '%d group' => '%d grupa',
    'Group ID' => 'ID grupe',
    'External ID' => 'Vanjski ID',
    '%d users' => '%d korisnika',
    '%d user' => '%d korisnik',
    'Hide subtasks' => 'Sakrij pod-zadatke',
    'Show subtasks' => 'Prikaži pod-zadatke',
    'Authentication Parameters' => 'Parametri autentifikacije',
    'API Access' => 'API pristup',
    'No users found.' => 'Nema pronađenih korisnika.',
    'User ID' => 'ID korisnika',
    'Notifications are activated' => 'Obavještenja su aktivirana',
    'Notifications are disabled' => 'Obavještenja su onemogućena',
    'User disabled' => 'Korisnik onemogućen',
    '%d notifications' => '%d obavještenja',
    '%d notification' => '%d obavještenje',
    'There is no external integration installed.' => 'Nema instaliranih vanjskih integracija.',
    'You are not allowed to update tasks assigned to someone else.' => 'Nemaš dozvolu za ažuriranje zadataka dodijeljenih drugima.',
    'You are not allowed to change the assignee.' => 'Nemaš dozvolu za promjenu izvršioca.',
    'Task suppression is not permitted' => 'Brisanje zadatka nije dozvoljeno',
    'Changing assignee is not permitted' => 'Promjena izvršioca nije dozvoljena',
    'Update only assigned tasks is permitted' => 'Ažuriranje samo dodijeljenih zadataka je dozvoljeno',
    'Only for tasks assigned to the current user' => 'Samo za zadatke dodijeljene trenutnom korisniku',
    'My projects' => 'Moji projekti',
    'You are not a member of any project.' => 'Nisi član ni jednog projekta.',
    'My subtasks' => 'Moji pod-zadaci',
    '%d subtasks' => '%d pod-zadataka',
    '%d subtask' => '%d pod-zadatak',
    'Only moving task between those columns is permitted for tasks assigned to the current user' => 'Pomijeranje zadataka između ovih kolona je dozvoljeno samo za zadatke dodijeljene trenutnom korisniku',
    '[DUPLICATE]' => '[DUPLIKAT]',
    'DKK - Danish Krona' => 'DKK - Danska kruna',
    'Remove user from group' => 'Ukloni korisnika iz grupe',
    'Assign the task to its creator' => 'Dodijeli zadatak njegovom kreatoru',
    'This task was sent by email to "%s" with subject "%s".' => 'Ovaj zadatak je poslan email-om "%s" sa predmetom "%s".',
    'Predefined Email Subjects' => 'Predefinisani predmeti email-a',
    'Write one subject by line.' => 'Napiši jedan predmet po liniji.',
    'Create another link' => 'Kreiraj drugu vezu',
    'BRL - Brazilian Real' => 'BRL - Brazilski real',
    'Add a new Kanboard task' => 'Dodaj novi Kanboard zadatak',
    'Subtask not started' => 'Pod-zadatak nije započet',
    'Subtask currently in progress' => 'Pod-zadatak trenutno u toku',
    'Subtask completed' => 'Pod-zadatak završen',
    'Subtask added successfully.' => 'Pod-zadatak uspješno dodan.',
    '%d subtasks added successfully.' => '%d pod-zadataka uspješno dodano.',
    'Enter one subtask by line.' => 'Unesi jedan pod-zadatak po liniji.',
    'Predefined Contents' => 'Predefinisani sadržaji',
    'Predefined contents' => 'Predefinisani sadržaji',
    'Predefined Task Description' => 'Predefinisani opis zadatka',
    'Do you really want to remove this template? "%s"' => 'Da li zaista želiš ukloniti ovaj šablon? "%s"',
    'Add predefined task description' => 'Dodaj predefinisani opis zadatka',
    'Predefined Task Descriptions' => 'Predefinisani opisi zadataka',
    'Template created successfully.' => 'Šablon uspješno kreiran.',
    'Unable to create this template.' => 'Nemoguće kreirati ovaj šablon.',
    'Template updated successfully.' => 'Šablon uspješno ažuriran.',
    'Unable to update this template.' => 'Nemoguće ažurirati ovaj šablon.',
    'Template removed successfully.' => 'Šablon uspješno uklonjen.',
    'Unable to remove this template.' => 'Nemoguće ukloniti ovaj šablon.',
    'Template for the task description' => 'Šablon za opis zadatka',
    'The start date is greater than the end date' => 'Početni datum je veći od krajnjeg datuma',
    'Tags must be separated by a comma' => 'Oznake moraju biti odvojene zarezom',
    'Only the task title is required' => 'Samo je naslov zadatka obavezan',
    'Creator Username' => 'Korisničko ime kreatora',
    'Color Name' => 'Naziv boje',
    'Column Name' => 'Naziv kolone',
    'Swimlane Name' => 'Naziv swimlane trake',
    'Time Estimated' => 'Procijenjeno vrijeme',
    'Time Spent' => 'Utrošeno vrijeme',
    'External Link' => 'Vanjska veza',
    'This feature enables the iCal feed, RSS feed and the public board view.' => 'Ova funkcionalnost omogućava iCal feed, RSS feed i javni pregled ploče.',
    'Stop the timer of all subtasks when moving a task to another column' => 'Zaustavi tajmer svih pod-zadataka kada se zadatak premjesti u drugu kolonu',
    'Subtask Title' => 'Naslov pod-zadatka',
    'Add a subtask and activate the timer when moving a task to another column' => 'Dodaj pod-zadatak i aktiviraj tajmer kada se zadatak premjesti u drugu kolonu',
    'days' => 'dana',
    'minutes' => 'minuta',
    'seconds' => 'sekundi',
    'Assign automatically a color when preset start date is reached' => 'Automatski dodijeli boju kada se dostigne unaprijed postavljeni početni datum',
    'Move the task to another column once a predefined start date is reached' => 'Premjesti zadatak u drugu kolonu kada se dostigne unaprijed postavljeni početni datum',
    'This task is now linked to the task %s with the relation "%s"' => 'Ovaj zadatak je sada povezan sa zadatkom %s sa relacijom "%s"',
    'The link with the relation "%s" to the task %s has been removed' => 'Veza sa relacijom "%s" prema zadatku %s je uklonjena',
    'Custom Filter:' => 'Prilagođeni filter:',
    'Unable to find this group.' => 'Nemoguće pronaći ovu grupu.',
    '%s moved the task #%d to the column "%s"' => '%s je premjestio zadatak #%d u kolonu "%s"',
    '%s moved the task #%d to the position %d in the column "%s"' => '%s je premjestio zadatak #%d na poziciju %d u koloni "%s"',
    '%s moved the task #%d to the swimlane "%s"' => '%s je premjestio zadatak #%d u swimlane traku "%s"',
    '%sh spent' => '%sh utrošeno',
    '%sh estimated' => '%sh procijenjeno',
    'Select All' => 'Označi sve',
    'Unselect All' => 'Poništi sve',
    'Apply action' => 'Primijeni akciju',
    'Move selected tasks to another column or swimlane' => 'Premjesti odabrane zadatke u drugu kolonu ili swimlane traku',
    'Edit tasks in bulk' => 'Uredi zadatke u rinfuzi',
    'Choose the properties that you would like to change for the selected tasks.' => 'Izaberi svojstva koja želiš promijeniti za odabrane zadatke.',
    'Configure this project' => 'Konfiguriši ovaj projekat',
    'Start now' => 'Počni sada',
    '%s removed a file from the task #%d' => '%s je uklonio datoteku sa zadatka #%d',
    'Attachment removed from task #%d: %s' => 'Prilog uklonjen sa zadatka #%d: %s',
    'No color' => 'Bez boje',
    'Attachment removed "%s"' => 'Prilog uklonjen "%s"',
    '%s removed a file from the task %s' => '%s je uklonio datoteku sa zadatka %s',
    'Move the task to another swimlane when assigned to a user' => 'Premjesti zadatak u drugu swimlane traku kada je dodijeljen korisniku',
    'Destination swimlane' => 'Odredišna swimlane traka',
    'Assign a category when the task is moved to a specific swimlane' => 'Dodijeli kategoriju kada je zadatak premješten u određenu swimlane traku',
    'Move the task to another swimlane when the category is changed' => 'Premjesti zadatak u drugu swimlane traku kada je kategorija promijenjena',
    'Reorder this column by priority (ASC)' => 'Presortiraj ovu kolonu po prioritetu (ASC)',
    'Reorder this column by priority (DESC)' => 'Presortiraj ovu kolonu po prioritetu (DESC)',
    'Reorder this column by assignee and priority (ASC)' => 'Presortiraj ovu kolonu po izvršiocu i prioritetu (ASC)',
    'Reorder this column by assignee and priority (DESC)' => 'Presortiraj ovu kolonu po izvršiocu i prioritetu (DESC)',
    'Reorder this column by assignee (A-Z)' => 'Presortiraj ovu kolonu po izvršiocu (A-Z)',
    'Reorder this column by assignee (Z-A)' => 'Presortiraj ovu kolonu po izvršiocu (Z-A)',
    'Reorder this column by due date (ASC)' => 'Presortiraj ovu kolonu po datumu završetka (ASC)',
    'Reorder this column by due date (DESC)' => 'Presortiraj ovu kolonu po datumu završetka (DESC)',
    'Reorder this column by id (ASC)' => 'Presortiraj ovu kolonu po ID-u (ASC)',
    'Reorder this column by id (DESC)' => 'Presortiraj ovu kolonu po ID-u (DESC)',
    '%s moved the task #%d "%s" to the project "%s"' => '%s je premjestio zadatak #%d "%s" u projekat "%s"',
    'Task #%d "%s" has been moved to the project "%s"' => 'Zadatak #%d "%s" je premješten u projekat "%s"',
    'Move the task to another column when the due date is less than a certain number of days' => 'Premjesti zadatak u drugu kolonu kada je datum završetka manji od određenog broja dana',
    'Automatically update the start date when the task is moved away from a specific column' => 'Automatski ažuriraj početni datum kada je zadatak premješten iz određene kolone',
    'HTTP Client:' => 'HTTP klijent:',
    'Assigned' => 'Dodijeljen',
    'Task limits apply to each swimlane individually' => 'Ograničenja zadataka se primjenjuju na svaku swimlane traku pojedinačno',
    'Column task limits apply to each swimlane individually' => 'Ograničenja zadataka u koloni se primjenjuju na svaku swimlane traku pojedinačno',
    'Column task limits are applied to each swimlane individually' => 'Ograničenja zadataka u koloni se primjenjuju na svaku swimlane traku pojedinačno',
    'Column task limits are applied across swimlanes' => 'Ograničenja zadataka u koloni se primjenjuju na sve swimlane trake',
    'Task limit: ' => 'Ograničenje zadatka: ',
    'Change to global tag' => 'Promijeni u globalnu oznaku',
    'Do you really want to make the tag "%s" global?' => 'Da li zaista želiš učiniti oznaku "%s" globalnom?',
    'Enable global tags for this project' => 'Omogući globalne oznake za ovaj projekat',
    'Group membership(s):' => 'Članstvo u grupi:',
    '%s is a member of the following group(s): %s' => '%s je član sljedećih grupa: %s',
    '%d/%d group(s) shown' => '%d/%d grupa prikazano',
    'Subtask creation or modification' => 'Kreiranje ili izmjena pod-zadatka',
    'Assign the task to a specific user when the task is moved to a specific swimlane' => 'Dodijeli zadatak određenom korisniku kada je zadatak premješten u određenu swimlane traku',
    'Comment' => 'Komentar',
    'Collapse vertically' => 'Skupi vertikalno',
    'Expand vertically' => 'Proširi vertikalno',
    'MXN - Mexican Peso' => 'MXN - Meksički pezo',
    'Estimated vs actual time per column' => 'Procijenjeno naspram stvarnog vremena po koloni',
    'HUF - Hungarian Forint' => 'HUF - Mađarski forint',
    'XBT - Bitcoin' => 'XBT - Bitcoin',
    'You must select a file to upload as your avatar!' => 'Morate odabrati datoteku za otpremanje kao svoj avatar!',
    'The file you uploaded is not a valid image! (Only *.gif, *.jpg, *.jpeg and *.png are allowed!)' => 'Datoteka koju ste otpremili nije važeća slika! (Dozvoljeni su samo *.gif, *.jpg, *.jpeg i *.png!)',
    'Automatically set the due date when the task is moved away from a specific column' => 'Automatski postavi rok kada se zadatak premjesti iz određene kolone',
    'No other projects found.' => 'Nema pronađenih drugih projekata.',
    'Tasks copied successfully.' => 'Zadaci su uspješno kopirani.',
    'Unable to copy tasks.' => 'Nije moguće kopirati zadatke.',
    'Theme' => 'Tema',
    'Theme:' => 'Tema:',
    'Light theme' => 'Svijetla tema',
    'Dark theme' => 'Tamna tema',
    'Automatic theme - Sync with system' => 'Automatska tema - Sinhronizacija sa sistemom',
    'Application managers or more' => 'Menadžeri aplikacije ili više',
    'Administrators' => 'Administratori',
    'Visibility:' => 'Vidljivost:',
    'Standard users' => 'Standardni korisnici',
    'Visibility is required' => 'Vidljivost je obavezna',
    'The visibility should be an app role' => 'Vidljivost treba biti uloga aplikacije',
    'Reply' => 'Odgovori',
    '%s wrote: ' => '%s je napisao: ',
    'Number of visible tasks in this column and swimlane' => 'Broj vidljivih zadataka u ovoj koloni i plivačkoj stazi',
    'Number of tasks in this swimlane' => 'Broj zadataka u ovoj plivačkoj stazi',
    'Unable to find another subtask in progress, you can close this window.' => 'Nije moguće pronaći drugu podzadatak u toku, možete zatvoriti ovaj prozor.',
    'This theme is invalid' => 'Ova tema nije važeća',
    'This role is invalid' => 'Ova uloga nije važeća',
    'This timezone is invalid' => 'Ova vremenska zona nije važeća',
    'This language is invalid' => 'Ovaj jezik nije važeći',
    'This URL is invalid' => 'Ovaj URL nije važeći',
    'Date format invalid' => 'Nevažeći format datuma',
    'Time format invalid' => 'Nevažeći format vremena',
    'Invalid Mail transport' => 'Nevažeći mail transport',
    'Color invalid' => 'Nevažeća boja',
    'This value must be greater or equal to %d' => 'Ova vrijednost mora biti veća ili jednaka %d',
    'Add a BOM at the beginning of the file (required for Microsoft Excel)' => 'Dodajte BOM na početak datoteke (potrebno za Microsoft Excel)',
    'Just add these tag(s)' => 'Dodajte samo ove oznake',
    'Remove internal link(s)' => 'Uklonite interne veze',
    'Import tasks from another project' => 'Uvezite zadatke iz drugog projekta',
    'Select the project to copy tasks from' => 'Odaberite projekat iz kojeg želite kopirati zadatke',
    'The total maximum allowed attachments size is %sB.' => 'Ukupna maksimalna dozvoljena veličina priloga je %sB.',
    'Add attachments' => 'Dodajte priloge',
    'Task #%d "%s" is overdue' => 'Zadatak #%d "%s" je s iztečen сроком',
    'Enable notifications by default for all new users' => 'Omogući obavještenja po difoltu za sve nove korisnike',
];
